/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.admin.service.impl;

import java.util.List;
import java.util.Set;

import org.apache.commons.logging.*;

import com.rapidtransform.admin.dao.RoleDAO;
import com.rapidtransform.admin.dao.UserDAO;
import com.rapidtransform.admin.model.Role;
import com.rapidtransform.admin.model.User;
import com.rapidtransform.admin.model.UserRoleRelation;
import com.rapidtransform.admin.service.UserService;
import com.rapidtransform.core.service.SecurityService;

/**
 * @author Steve
 *
 */
public class UserServiceImpl implements UserService {
	private Log log = LogFactory.getLog(UserServiceImpl.class);
	private UserDAO userDAO;
	private RoleDAO roleDAO;
	private String defaultUserRole;
	private SecurityService securityService;
	
	public void setUserDAO(UserDAO userDAO) {
		this.userDAO = userDAO;
	}
	
	public void setSecurityService(SecurityService service) {
		this.securityService = service;
	}
	
	public void setDefaultUserRole(String userRole) {
		this.defaultUserRole = userRole;
	}

	public void setRoleDAO(RoleDAO roleDAO) {
		this.roleDAO = roleDAO;
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.service.UserService#getUser(java.lang.String)
	 */
	public User getUser(String userId) {
		User user = userDAO.getUser(userId);
		
		if (user == null) {
			log.warn("User "+userId+" not found");
		}
		
		return user;
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.service.UserService#getUsers()
	 */
	public List<User> getUsers() {
		return userDAO.getUsers();
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.service.UserService#saveUser(com.rapidtransform.model.User)
	 */
	public void saveUser(User user) {
		if (log.isDebugEnabled()) log.debug("Saving user: "+user+" with password: "+user.getPassword());
		// encode the password with SHA encoder
		String encPassword = securityService.encodePassword(user.getPassword());
		user.setPassword(encPassword);
		
		userDAO.saveUser(user);

		// check if this user has any roles assigned and if not, assign them to the ROLE_USER role automatically
		/*if (defaultUserRole != null) {
			List roles = roleDAO.getUserRoles(user.getUsername());
			if (roles.size() == 0) {
				UserRole role = new UserRole();
				role.setAuthority(defaultUserRole);
				role.setUsername(user.getUsername());
				roleDAO.saveUserRole(role);
			}
		}*/
		
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.service.UserService#removeUser(java.lang.String)
	 */
	public void removeUser(String userId) {
		userDAO.removeUser(userId);
	}
	
	public List<Role> getRoles() {
		return roleDAO.getRoles();
	}

	public Role getRole(String roleId) {
		return roleDAO.getRole(Long.valueOf(roleId));
	}

	public void saveRole(Role role) {
		roleDAO.saveRole(role);
	}

	public Set<UserRoleRelation> getUserRoles(String userId) {
		return userDAO.getUserRoles(userId);
	}

}
