/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.core.dao.hibernate;

import java.io.Serializable;
import java.sql.SQLException;
import java.util.List;

import org.hibernate.HibernateException;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.criterion.DetachedCriteria;
import org.springframework.orm.hibernate3.HibernateCallback;
import org.springframework.orm.hibernate3.support.HibernateDaoSupport;

import com.rapidtransform.core.dao.GenericDAO;
import com.rapidtransform.core.model.Model;
import com.rapidtransform.core.model.namespace.QName;
import com.rapidtransform.product.model.Product;
import com.rapidtransform.spec.model.Specification;

/**
 * @author Steve
 *
 */
public class GenericDAOHibernate<Type, ID extends Serializable> extends HibernateDaoSupport implements GenericDAO<Type, ID> {

    private Class<Type> persistentClass;
    
    public GenericDAOHibernate() {
    }
    
    public GenericDAOHibernate(Class<Type> persistentClass) {
        this.persistentClass = persistentClass;
    }

    public void setPersistentClass(Class<Type> persistentClass) {
    	this.persistentClass = persistentClass;
    }
    
    public Class<Type> getPersistentClass() {
    	return persistentClass;
    }

    /* (non-Javadoc)
	 * @see com.rapidtransform.dao.GenericDAO#findById(ID, boolean)
	 */
	public Type findById(ID id) {
		return (Type) getHibernateTemplate().get(getPersistentClass(), id);
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.dao.GenericDAO#findAll()
	 */
	public List<Type> findAll() {
		long start = System.currentTimeMillis();
		
		DetachedCriteria criteria = DetachedCriteria.forClass(getPersistentClass());
		//getHibernateTemplate().isAlwaysUseNewSession()
		List<Type> all = getHibernateTemplate().findByCriteria(criteria);
		long elapsed = System.currentTimeMillis() - start;
		System.out.println("dao.findAll() time: "+elapsed);
		return all;
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.dao.GenericDAO#save(Type)
	 */
	public Type save(Type entity) {
		getHibernateTemplate().saveOrUpdate(entity);
		return entity;
	}

	public void remove(Type entity) {
		getHibernateTemplate().delete(entity);
	}
	
	/* (non-Javadoc)
	 * @see com.rapidtransform.core.dao.GenericDAO#findByType(com.rapidtransform.core.model.namespace.QName)
	 */
	@SuppressWarnings("unchecked")
	public List<Type> findByType(final QName metaType) {
		return (List<Type>)getHibernateTemplate().execute(new HibernateCallback() {
			public Object doInHibernate(Session session) throws HibernateException, SQLException {
				Query q = session.createQuery("from "+getPersistentClass().getName() + 
						" where metaTypeName=:metaType");
				q.setParameter("metaType", metaType);
				return q.list();
			}
		});
	}

}
