/**
 * 
 */
package com.rapidtransform.core.dao.hibernate;

import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.orm.hibernate3.support.HibernateDaoSupport;

import com.rapidtransform.core.ConveloException;
import com.rapidtransform.core.dao.RelationDAO;
import com.rapidtransform.core.meta.MetaService;
import com.rapidtransform.core.model.Relation;
import com.rapidtransform.core.model.namespace.Namespace;
import com.rapidtransform.core.model.namespace.NamespaceRelation;

/**
 * @author Steve Werner
 *
 */
public class MetaRelationDAOHibernate extends HibernateDaoSupport implements RelationDAO {
	
	private static Log log = LogFactory.getLog(MetaRelationDAOHibernate.class);
	
	/**
	 * This map contains the mapping between source-target namespaces and the appropriate database entity for 
	 * saving the relation.  Each namespace maps to exactly one M1 class so a new hibernate entity will need to be created for
	 * each unique source-target namespace pair.
	 */
	private Map<NamespaceRelation, String> relationEntities;
	private MetaService metaService;
	
	/**
	 * @return Returns the relationEntities.
	 */
	public Map<NamespaceRelation, String> getRelationEntities() {
		return relationEntities;
	}

	/**
	 * @param relationEntities The relationEntities to set.
	 */
	public void setRelationEntities(Map<NamespaceRelation, String> relationEntities) {
		this.relationEntities = relationEntities;
	}

	/**
	 * @return Returns the metaService.
	 */
	public MetaService getMetaService() {
		return metaService;
	}

	/**
	 * @param metaService The metaService to set.
	 */
	public void setMetaService(MetaService metaService) {
		this.metaService = metaService;
	}

	/* 
	 * @see com.rapidtransform.core.dao.RelationDAO#save(com.rapidtransform.core.model.Relation)
	 */
	public Relation save(Relation relation) throws ConveloException {
		
		// look up the namespaces for the source and target meta types for the relation
		Namespace sourceNS = metaService.getNamespace(relation.getSource().getMetaTypeName());
		Namespace targetNS = metaService.getNamespace(relation.getTarget().getMetaTypeName());
		
		// get the entity-name for the relation being saved
		String entityName = relationEntities.get(new NamespaceRelation(sourceNS, targetNS));
		if (entityName == null) {
			log.error("No entity relation mapping found for source "+sourceNS+" and target "+targetNS+" namespaces");
			throw new ConveloException("No entity relation mapping found for source "+sourceNS+" and target "+targetNS+" namespaces");
		}
		getHibernateTemplate().saveOrUpdate(entityName, relation);
		return relation;
	}
	
}
