/**
 * 
 */
package com.rapidtransform.core.meta;

import java.util.Collection;
import java.util.Map;

import com.rapidtransform.core.model.namespace.Namespace;
import com.rapidtransform.core.model.namespace.QName;

/**
 * The Dictionary contains the loaded meta models and provides some convenience operations for
 * the models.
 * 
 * @author Steve Werner
 *
 */
public interface Dictionary {
	public void addModel(MetaModel model);
	
	public void removeModel(QName qName) throws MetaException;
	
	public MetaModel getModel(QName qName);
	
	public Map<QName, MetaModel> getLoadedModels();
	
	public MetaType getType(QName qName);
	
	public MetaProperty getProperty(String propertyName);
	
	/**
	 * Returns the qualified name for the given namespace.
	 * @param namespace
	 * @return
	 */
	public QName getQName(Namespace namespace);
	
	/**
	 * Returns the namespace associated with the given Meta Type.
	 * 
	 * @param type
	 * @return
	 */
	public Namespace getNamespace(QName type);
	
	/**
	 * Returns a list of all searchable Meta Types defined for the application.
	 * 
	 * @return
	 */
	public Collection<MetaType> getSearchableTypes();
}
