/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 with a permitted attribution clause (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.rapidtransform.com/legal/license.txt
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Convelo Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 */
package com.rapidtransform.core.meta;

import java.io.InputStream;
import java.util.Collection;

import com.rapidtransform.core.model.namespace.Namespace;
import com.rapidtransform.core.model.namespace.QName;
import com.rapidtransform.core.type.PropertyHolder;

/**
 * Meta service for loading and accessing meta models and components.
 * 
 * @author Steve Werner
 *
 */
public interface MetaService {
	
	public void load() throws MetaException;
	
	public MetaModel loadModel(InputStream modelStream) throws MetaException;
	
	public void addModel(MetaModel model);
	
	public void removeModel(QName qName);
	
	public Collection<MetaModel> getLoadedModels();
	
	public MetaModel getLoadedModel(QName qName);
	
	public MetaModel getLoadedModel(Namespace namespace) throws MetaException;
	
	public MetaType getType(QName qname) throws MetaException;
	public MetaType getType(String qname) throws MetaException;
	
	public PropertyHolder getProperties(QName type) throws MetaException;
	public PropertyHolder getProperties(String typeQname) throws MetaException;
	
	public MetaProperty getProperty(String fullyQualifiedPropertyName) throws MetaException;
	
	public Namespace getNamespace(QName type);
	
	/**
	 * Checks if the specified relation is valid for the given type and returns the target type if the 
	 * relation is valid.  If it is an invalid relation, then an exception is thrown. 
	 * 
	 * @param type	QName for the source for the relation
	 * @param relation	QName for the relation
	 * @return The QName representing the type of the target
	 * @throws InvalidMetaRelationException
	 */
	public QName getRelationTarget(QName type, QName relation) throws MetaException, InvalidMetaRelationException;
	
	public Collection<MetaType> getSearchableTypes() throws MetaException;
	
}
