/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 with a permitted attribution clause (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.rapidtransform.com/legal/license.txt
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Convelo Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 */
package com.rapidtransform.core.meta.def;

import java.io.InputStream;
import java.io.OutputStream;
import java.util.Collection;
import java.util.Date;
import java.util.Map;

import org.jibx.runtime.BindingDirectory;
import org.jibx.runtime.IBindingFactory;
import org.jibx.runtime.IMarshallingContext;
import org.jibx.runtime.IUnmarshallingContext;
import org.jibx.runtime.JiBXException;

import com.rapidtransform.core.meta.MetaAspect;
import com.rapidtransform.core.meta.MetaException;
import com.rapidtransform.core.meta.MetaInclude;
import com.rapidtransform.core.meta.MetaModel;
import com.rapidtransform.core.meta.MetaNamespace;
import com.rapidtransform.core.meta.MetaProperty;
import com.rapidtransform.core.meta.MetaType;
import com.rapidtransform.core.model.XMLMarshalingException;
import com.rapidtransform.core.model.XMLSerializable;
import com.rapidtransform.core.model.namespace.QName;

/**
 * @author Steve
 *
 */
public class BaseMetaModel implements MetaModel, XMLSerializable {
	
	private QName name;
	private String display;
	private String description;
	private String author;
	private String version;
	private Date published;
	private Collection<MetaInclude> includes;
	private Map<QName, MetaProperty> properties;
	private Collection<MetaType> types;
	private Collection<MetaAspect> aspects;
	private Collection<MetaNamespace> namespaces;
	
	
	/**
	 * @return Returns the author.
	 */
	public String getAuthor() {
		return author;
	}
	/**
	 * @param author The author to set.
	 */
	public void setAuthor(String author) {
		this.author = author;
	}
	/**
	 * @return Returns the description.
	 */
	public String getDescription() {
		return description;
	}
	/**
	 * @param description The description to set.
	 */
	public void setDescription(String description) {
		this.description = description;
	}
	/**
	 * @return Returns the display.
	 */
	public String getDisplay() {
		return display;
	}
	/**
	 * @param display The display to set.
	 */
	public void setDisplay(String display) {
		this.display = display;
	}
	/**
	 * @return Returns the includes.
	 */
	public Collection<MetaInclude> getIncludes() {
		return includes;
	}
	/**
	 * @param includes The includes to set.
	 */
	public void setIncludes(Collection<MetaInclude> includes) {
		this.includes = includes;
	}
	/**
	 * @return Returns the properties.
	 */
	public Map<QName, MetaProperty> getProperties() {
		return properties;
	}
	/**
	 * @param properties The properties to set.
	 */
	public void setProperties(Map<QName, MetaProperty> properties) {
		this.properties = properties;
	}
	/**
	 * @return Returns the published.
	 */
	public Date getPublished() {
		return published;
	}
	/**
	 * @param published The published to set.
	 */
	public void setPublished(Date published) {
		this.published = published;
	}
	/**
	 * @return Returns the qname.
	 */
	public QName getName() {
		return name;
	}
	/**
	 * @param qname The qname to set.
	 */
	public void setName(QName qname) {
		this.name = qname;
	}
	/**
	 * @return Returns the types.
	 */
	public Collection<MetaType> getTypes() {
		return types;
	}
	/**
	 * @param types The types to set.
	 */
	public void setTypes(Collection<MetaType> types) {
		this.types = types;
	}
	/**
	 * @return Returns the version.
	 */
	public String getVersion() {
		return version;
	}
	/**
	 * @param version The version to set.
	 */
	public void setVersion(String version) {
		this.version = version;
	}
	/**
	 * @return Returns the aspects.
	 */
	public Collection<MetaAspect> getAspects() {
		return aspects;
	}
	/**
	 * @param aspects The aspects to set.
	 */
	public void setAspects(Collection<MetaAspect> aspects) {
		this.aspects = aspects;
	}
	/**
	 * @return Returns the namespaces.
	 */
	public Collection<MetaNamespace> getNamespaces() {
		return namespaces;
	}
	/**
	 * @param namespaces The namespaces to set.
	 */
	public void setNamespaces(Collection<MetaNamespace> namespaces) {
		this.namespaces = namespaces;
	}
	
	public static MetaModel fromXML(InputStream xmlInput) throws XMLMarshalingException {
		try
        {
            IBindingFactory factory = BindingDirectory.getFactory(BaseMetaModel.class);
            IUnmarshallingContext context = factory.createUnmarshallingContext();
            Object obj = context.unmarshalDocument(xmlInput, null);
            return (MetaModel)obj;
        }
        catch(JiBXException e)
        {
            throw new XMLMarshalingException("Failed to parse model", e);
        }
	}
	
	/**
	 * Creates a MetaModel from an XML Input Stream.
	 */
	public XMLSerializable unmarshal(InputStream xmlInput) throws XMLMarshalingException {
		return (XMLSerializable)fromXML(xmlInput);
	}
	
	/**
	 * creates the xml representation of the MetaModel
	 */
	public void marshal(OutputStream xmlOutput) throws XMLMarshalingException {
		try
        {
            IBindingFactory factory = BindingDirectory.getFactory(BaseMetaModel.class);
            IMarshallingContext context = factory.createMarshallingContext();
            context.marshalDocument(this, "UTF-8", null, xmlOutput);    
        }
        catch(JiBXException jbxe)
        {
            throw new XMLMarshalingException("Error marshaling MetaModel to XML", jbxe);
        } 
	}
	
	public QName getQname() {
		return name;
	}
	
}
