/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.core.model;

import java.io.Serializable;
import java.util.Collection;
import java.util.Collections;
import java.util.Map;
import java.util.UUID;

import com.rapidtransform.core.model.namespace.QName;
import com.rapidtransform.core.type.PropertyHolder;
import com.rapidtransform.core.util.EqualsUtil;

/**
 * Base class for Model objects.  This class implements basic functionality for Model objects, for example
 * toString, equals, and hashCode methods.
 *
 */
public abstract class AbstractBaseModel implements Serializable, Model {

	private static final long serialVersionUID = 2371457189315613393L;
	
	private String uuid;  // TODO map as the primary key for all Model objects in database
	private Long id;
	private QName metaTypeName;
	private PropertyHolder propertyHolder;
	
	public Long getId() {
		return id;
	}
	
	public void setId(Long id) {
		this.id = id;
	}

	public void setUuid(String id) {
		this.uuid = id;
	}
	
	public String getUuid() {
		if (uuid == null) {
			this.uuid = UUID.randomUUID().toString();
		}
		return uuid;
	}
	
	public String generateUuid() {
		this.uuid = UUID.randomUUID().toString();
		return this.uuid;
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.core.model.Model#getMetaTypeName()
	 */
	public QName getMetaTypeName() {
		return metaTypeName;
	}
	
	public void setMetaTypeName(QName qName) {
		this.metaTypeName = qName;
	}

	/**
	 * @return Returns the propertyHolder.
	 */
	public PropertyHolder getPropertyHolder() {
		return propertyHolder;
	}

	/**
	 * @param propertyHolder The propertyHolder to set.
	 */
	public void setPropertyHolder(PropertyHolder propertyHolder) {
		this.propertyHolder = propertyHolder;
	}

	public boolean equals(Object other) {
		return (EqualsUtil.areEqual(this.uuid, ((Model)other).getUuid()) &&
				EqualsUtil.areEqual(this.metaTypeName, ((Model)other).getMetaTypeName()) &&
				EqualsUtil.areEqual(this.getId(), ((Model)other).getId()));
	}

	public int hashCode() {
		return getUuid().hashCode();
	}
}
