/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 with a permitted attribution clause (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.rapidtransform.com/legal/license.txt
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Convelo Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 */
package com.rapidtransform.core.model.namespace;

import java.io.Serializable;

import com.rapidtransform.core.util.EqualsUtil;

/**
 * @author Steve
 *
 */
public class QName implements Serializable {
	private String uri;
	private String localName;
	private String prefix;
	
	public QName() {	
	}
	
	public QName(String qName) {
		int index = qName.indexOf(":");
		prefix = qName.substring(0, index);
		localName = qName.substring(index+1, qName.length());
	}
	
	/**
	 * @param localName The localName to set.
	 */
	public void setLocalName(String localName) {
		this.localName = localName;
	}

	/**
	 * @param prefix The prefix to set.
	 */
	public void setPrefix(String prefix) {
		this.prefix = prefix;
	}

	/**
	 * @param uri The uri to set.
	 */
	public void setUri(String uri) {
		this.uri = uri;
	}

	/**
	 * @return Returns the localName.
	 */
	public String getLocalName() {
		return localName;
	}

	/**
	 * @return Returns the prefix.
	 */
	public String getPrefix() {
		return prefix;
	}

	/**
	 * @return Returns the uri.
	 */
	public String getUri() {
		return uri;
	}

	QName(String prefix, String name, String uri) {
		this.uri = uri;
		this.localName = name;
		this.prefix = prefix;
	}
	
	public boolean equals(Object obj) {
		return (EqualsUtil.areEqual(this.prefix, ((QName)obj).getPrefix()) &&
				EqualsUtil.areEqual(this.localName, ((QName)obj).getLocalName()));
	}
	
	public int hashCode() {
		return 23 * this.prefix.hashCode() * this.localName.hashCode();
	}

	public String toString() {
		return (prefix == null) ? this.localName : this.prefix + ":" + this.localName;
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.core.model.namespace.QName#getNamespaceURI()
	 */
	public String getNamespaceURI() {
		return this.uri;
	}
	
	/**
	 * Returns an encoded string for the QName where the : is replaced with an _ character.  This is necessary
	 * for encoding the string in functionality that does not accept the colon as a valid character - such
	 * as storing to the file system or as an HTML id.
	 * @return
	 */
	public String toEncodedString() {
		return this.toString().replace(":", "_");
	}
}
