/**
 * 
 */
package com.rapidtransform.core.search.lucene;

import java.io.ByteArrayInputStream;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.compass.core.Property;
import org.compass.core.config.CompassConfiguration;
import org.compass.spring.LocalCompassBean;

import com.rapidtransform.core.meta.MetaModel;
import com.rapidtransform.core.meta.MetaService;
import com.rapidtransform.core.meta.MetaType;
import com.rapidtransform.core.meta.MetaProperty;;

/**
 * @author Steve Werner
 *
 */
public class MetaCompassBean extends LocalCompassBean {
	
	private static Log log = LogFactory.getLog(MetaCompassBean.class);
	
	private MetaService metaService;
	
	/**
	 * @return Returns the metaService.
	 */
	public MetaService getMetaService() {
		return metaService;
	}

	/**
	 * @param metaService The metaService to set.
	 */
	public void setMetaService(MetaService metaService) {
		this.metaService = metaService;
	}

	/* (non-Javadoc)
	 * @see org.compass.spring.LocalCompassBean#afterPropertiesSet()
	 */
	@Override
	public void afterPropertiesSet() throws Exception {
		CompassConfiguration compassconfig = newConfiguration();
		//config.
		String config = "<?xml version='1.0'?>" +
				"<!DOCTYPE compass-core-mapping PUBLIC '-//Compass/Compass Core Mapping DTD 1.0//EN' " +
				"'http://www.opensymphony.com/compass/dtd/compass-core-mapping.dtd'><compass-core-mapping>";
				
		// iterate through each model, it's types and the properties for that type to determine what should be indexed
		// and how each property should be indexed
		for (MetaModel model : metaService.getLoadedModels()) {
			for (MetaType type : model.getTypes()) {
				config = config + "<resource alias='"+type.getName().toEncodedString()+"'><resource-id name='id' />";
				for (MetaProperty prop : type.getProperties()) {
					config = config + "<resource-property name='"+prop.getName()+"' store='yes' index='tokenized'/>";
				}
				config = config + "</resource>";
			}
		}
		config = config + "</compass-core-mapping>";
		log.debug("Adding search engine resource configuration: "+config);
		ByteArrayInputStream bais = new ByteArrayInputStream(config.getBytes());
		compassconfig.addInputStream(bais, "convelo-meta.cpm.xml");
		
		this.setCompassConfiguration(compassconfig);
		
		super.afterPropertiesSet();
	}
	
}
