/**
 * 
 */
package com.rapidtransform.core.service;

import java.util.List;

import com.rapidtransform.core.ConveloException;
import com.rapidtransform.core.meta.InvalidMetaRelationException;
import com.rapidtransform.core.meta.MetaException;
import com.rapidtransform.core.model.Model;
import com.rapidtransform.core.model.Relation;
import com.rapidtransform.core.model.namespace.QName;

/**
 * @author Steve Werner
 *
 */
public interface MetaCRUDService<Type extends Model> extends CRUDService<Type> {
	
	/**
	 * Creates an M1 object with the given Meta type specified by the QName.
	 * @param qname
	 * @return Model entity with it's meta attributes initialized
	 * @throws MetaException 
	 */
	public Type create(QName qname) throws MetaException;
	
	
	/**
	 * Creates a relation with the given type between the source and target models.  If the relation
	 * is not defined in the Meta mapping for the source, then an InvalidMetaRelationException is thrown.
	 * 
	 * After the relation is created it is saved to the database and returned.
	 * 
	 * @param source
	 * @param target
	 * @param relationType
	 * @return
	 */
	public Relation createRelation(Type source, Model target, QName relationType) throws ConveloException, InvalidMetaRelationException;
	
	/**
	 * Returns all instances with the given metaType.
	 * 
	 * @param metaType
	 * @return
	 */
	public List<Type> findByMetaType(String metaTypeQName);
	
}
