/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.core.service;

import java.util.Collection;
import java.util.List;

import org.springframework.transaction.annotation.Transactional;

import com.rapidtransform.core.ConveloException;
import com.rapidtransform.core.model.ValidValue;

/**
 * @author Steve
 *
 */
public interface ValidValueService extends Service {
	/**
	 * Creates or updates the given ValidValue object to the database.  This is a generic service
	 * method to be used by all subclass types of ValidValue.
	 * 
	 * @param validValue
	 * @return Saved ValidValue object
	 * @throws ConveloException
	 */
	@Transactional(rollbackFor=ConveloException.class)
	public ValidValue save(ValidValue validValue) throws ConveloException;
	
	/**
	 * Returns the ValidValue object for the given subclass and id.
	 * 
	 * @param id
	 * @return ValidValue
	 * @throws ConveloException
	 */
	public ValidValue find(Class subclass, Long id) throws ConveloException;
	
	
	/**
	 * Returns a collection of all the ValidValues for the given ValidValue subclass.  The collection contains
	 * all enabled <strong>and</strong> disabled values.
	 * 
	 * @param validValueClass
	 * @return Collection of ValidValue objects
	 * @throws ConveloException Exception generated if subclass is not mapped in the validValueDAOs map
	 */
	public Collection<ValidValue> findAll(Class subclass) throws ConveloException;
	
	/**
	 * Returns a collection of all enabled ValidValues for the given ValidValue subclass.
	 * 
	 * @param subclass
	 * @return
	 * @throws ConveloException
	 */
	public Collection<ValidValue> findEnabled(Class subclass) throws ConveloException;
	
	/**
	 * Returns a collection of existing value list types.
	 * @return Collection of ValidValue classes
	 */
	public Collection<String> getValueListTypes();
	
	/**
	 * Removes the given valid value from the database.
	 * 
	 * @param validValue
	 * @exception ConveloException
	 */
	public void remove(ValidValue validValue) throws ConveloException;

}
