/**
 * The contents of this file are subject to the Rapid Transform Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.rapidtransform.com/license.html
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.core.service.impl;

import java.util.Date;
import java.util.List;

import org.apache.commons.logging.Log;
import org.springframework.transaction.annotation.Transactional;

import com.rapidtransform.core.ConveloException;
import com.rapidtransform.core.dao.GenericDAO;
import com.rapidtransform.core.model.VersionControlled;
import com.rapidtransform.core.service.CRUDService;

/**
 * @author S. Werner
 *
 */
public abstract class CRUDServiceImpl<Type> extends ServiceImpl implements CRUDService<Type> {
    
	private Class<Type> persistentClass;
	private GenericDAO<Type, Long> dao;
    
    public CRUDServiceImpl() {
    }
    
    public CRUDServiceImpl(Class<Type> persistentClass) {
        this.persistentClass = persistentClass;
    }

    public void setPersistentClass(Class<Type> persistentClass) {
    	this.persistentClass = persistentClass;
    }
    
    public Class<Type> getPersistentClass() {
    	return persistentClass;
    }
    
    public void setDao(GenericDAO<Type, Long> genericDao) {
    	this.dao = genericDao;
    }
    public GenericDAO<Type, Long> getDao() {
    	return this.dao;
    }
    
    public abstract Log getLog();
    
	public Type create() throws ConveloException {
		Type entity = null;
		try {
			entity = getPersistentClass().newInstance();
		} catch (Exception iae) {
			getLog().debug("Unable to instantiate persistent class: "+getPersistentClass());
			throw new ConveloException("Unable to instantiate persistent class: "+getPersistentClass(), iae);
		}
		if (entity instanceof VersionControlled) {
			((VersionControlled)entity).setCreatedDate(new Date());
			((VersionControlled)entity).setCreatedBy(getSecurityService().getAuthenticatedUser());
		}
		return entity;
	}

	@Transactional
	public Type save(Type entity) {
		if (entity instanceof VersionControlled) {
			((VersionControlled)entity).setModifiedDate(new Date());
			((VersionControlled)entity).setModifiedBy(getSecurityService().getAuthenticatedUser());
		}
		return (Type)dao.save(entity);
	}

	public Type find(Long id) {
		return (Type)dao.findById(id);
	}

	public List<Type> findAll() {
		long start = System.currentTimeMillis();
		List<Type> all = dao.findAll();
		long elapsed = System.currentTimeMillis() - start;
		getLog().debug("service.findAll() time: "+elapsed);
		return all;
	}

}
