/**
 * 
 */
package com.rapidtransform.core.service.impl;

import java.util.List;

import org.springframework.transaction.annotation.Transactional;

import com.rapidtransform.core.ConveloException;
import com.rapidtransform.core.dao.RelationDAO;
import com.rapidtransform.core.meta.InvalidMetaRelationException;
import com.rapidtransform.core.meta.MetaException;
import com.rapidtransform.core.meta.MetaService;
import com.rapidtransform.core.model.BaseRelation;
import com.rapidtransform.core.model.Model;
import com.rapidtransform.core.model.Relation;
import com.rapidtransform.core.model.namespace.QName;
import com.rapidtransform.core.service.MetaCRUDService;
import com.rapidtransform.product.model.Product;
import com.rapidtransform.product.model.ProductSpecRelation;
import com.rapidtransform.spec.model.SpecRelation;
import com.rapidtransform.spec.model.Specification;

/**
 * Service abstraction for M1 classes that implement the Model interface - ie. those containing meta information.
 * 
 * @author Steve Werner
 *
 */
public abstract class MetaCRUDServiceImpl<Type extends Model> extends CRUDServiceImpl<Type> implements MetaCRUDService<Type> {

	
	public MetaCRUDServiceImpl() {
    }
    
    public MetaCRUDServiceImpl(Class<Type> persistentClass) {
        super(persistentClass);
    }
    
	private MetaService metaService;
	private RelationDAO relationDao;
	/**
	 * @return Returns the metaService.
	 */
	public MetaService getMetaService() {
		return metaService;
	}

	/**
	 * @param metaService The metaService to set.
	 */
	public void setMetaService(MetaService metaService) {
		this.metaService = metaService;
	}
	
	/**
	 * @return Returns the relationDao.
	 */
	public RelationDAO getRelationDao() {
		return relationDao;
	}

	/**
	 * @param relationDao The relationDao to set.
	 */
	public void setRelationDao(RelationDAO relationDao) {
		this.relationDao = relationDao;
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.core.service.MetaCRUDService#create(com.rapidtransform.core.model.namespace.QName)
	 */
	public Type create(QName qname) throws MetaException {
		Type entity = null;
		try {
			entity = create();
			entity.setPropertyHolder(metaService.getProperties(qname));
		} catch (ConveloException re) {
			getLog().error("Could not create entity with Meta type "+qname, re);
			throw new MetaException("Could not create entity with Meta type "+qname, re);
		}
		return entity;
	}
	
	/**
	 * Creates a relation with the given type between the source and target models.  If the relation
	 * is not defined in the Meta mapping for the source, then an InvalidMetaRelationException is thrown.
	 * 
	 * After the relation is created it is saved to the database and returned.
	 * 
	 * @param source
	 * @param target
	 * @param relationType
	 * @return
	 */
	@Transactional
	public Relation createRelation(Type source, Model target, QName relationType) throws ConveloException, InvalidMetaRelationException {
		BaseRelation rel = new BaseRelation();
		rel.setSource(source);
		rel.setMetaTypeName(relationType);
		QName targetName = getMetaService().getRelationTarget(source.getMetaTypeName(), relationType);
		
		if (!targetName.equals(target.getMetaTypeName())) {
			throw new InvalidMetaRelationException("Target Meta type does not match Meta type in mapping");
		}
		rel.setTarget(target);
		
		// save the relation
		relationDao.save(rel);
		
		return rel;
	}
	
	/* (non-Javadoc)
	 * @see com.rapidtransform.core.service.MetaCRUDService#findByMetaType(java.lang.String)
	 */
	public List<Type> findByMetaType(String metaTypeQName) {
		return getDao().findByType(new QName(metaTypeQName));
	}

}
