/**
 * The contents of this file are subject to the Rapid Transform Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.rapidtransform.com/license.html
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.core.service.impl;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.acegisecurity.Authentication;
import org.acegisecurity.context.SecurityContextHolder;
import org.acegisecurity.providers.encoding.PasswordEncoder;

import com.rapidtransform.admin.dao.UserDAO;
import com.rapidtransform.admin.model.User;
import com.rapidtransform.core.service.SecurityService;

/**
 * Implementation of the SecurityService interface that is specific to the Acegi Security
 * framework for Spring.
 * 
 * @author S. Werner
 *
 */
public class SecurityServiceAcegi extends ServiceImpl implements SecurityService {
	private Log log = LogFactory.getLog(SecurityServiceAcegi.class);
	
	private UserDAO userDao;
	private PasswordEncoder passwordEncoder;

	public void setUserDao(UserDAO userDao) {
		this.userDao = userDao;
	}
	
	public void setPasswordEncoder(PasswordEncoder passwordEncoder) {
		this.passwordEncoder = passwordEncoder;
	}
	
	public String encodePassword(String password) {
		String encodedPassword = passwordEncoder.encodePassword(password, null);
		return encodedPassword;
	}

	public User getAuthenticatedUser() {
		try {
			Authentication auth = SecurityContextHolder.getContext().getAuthentication();
			String username = ((org.acegisecurity.userdetails.User)auth.getPrincipal()).getUsername();
			return userDao.getUser(username);
		} catch (Exception e) {
			log.error("Error retrieving current authenticated user");
		}
		return null;
	}

}
