/**
 * 
 */
package com.rapidtransform.core.type;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

import com.rapidtransform.core.model.namespace.QName;
import com.rapidtransform.core.util.EqualsUtil;

/**
 * This property holder utilizes the concept of a Hibernate dynamic-component to store the map of properties in 
 * the database.
 * 
 * @author Steve Werner
 *
 */
public class DynamicPropertyHolder implements PropertyHolder {

	private String uuid;
	private QName metaTypeName;
	private Map<String, Object> properties;
	
	public DynamicPropertyHolder() {
		properties = new HashMap<String, Object>();
		uuid = UUID.randomUUID().toString();
	}
	
	public Map<String, Object> getProperties() {
		return this.properties;
	}
	
	public void setProperties(Map<String, Object> props) {
		this.properties = props;
	}
	
	/**
	 * @return Returns the uuid.
	 */
	public String getUuid() {
		if (uuid == null || (uuid != null && uuid.length() <= 0)) {
			uuid = UUID.randomUUID().toString();
		}
		return uuid;
	}

	/**
	 * @param uuid The uuid to set.
	 */
	public void setUuid(String uuid) {
		this.uuid = uuid;
	}
	
	/**
	 * @return Returns the metaTypeName.
	 */
	public QName getMetaTypeName() {
		return metaTypeName;
	}

	/**
	 * @param metaTypeName The metaTypeName to set.
	 */
	public void setMetaTypeName(QName metaTypeName) {
		this.metaTypeName = metaTypeName;
	}

	public Object getProperty(String propertyName) {
		return (Serializable)properties.get(metaTypeName+":"+propertyName);
	}
	
	/* (non-Javadoc)
	 * @see com.rapidtransform.core.type.PropertyHolder#setValue(java.lang.String, java.io.Serializable)
	 */
	public void setProperty(String propertyName, Object value) {
		properties.put(this.metaTypeName+":"+propertyName, value);
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object that) {
		return (EqualsUtil.areEqual(getMetaTypeName(), ((PropertyHolder)that).getMetaTypeName()) && 
				EqualsUtil.areEqual(getUuid(), ((PropertyHolder)that).getUuid()));
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode() {
		return (this.uuid == null) ? 23 * this.metaTypeName.hashCode() : 23 * this.metaTypeName.hashCode() * this.getUuid().hashCode();
	}

}
