/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 with a permitted attribution clause (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.rapidtransform.com/legal/license.txt
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Convelo Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 */
package com.rapidtransform.core.type;

/**
 * Generic placeholder for custom properties.  the Type is specified by the generic DataType and the
 * persistent class can be specified using the given constructor or setter method.
 * 
 * @author S. Werner
 *
 */
public abstract class GenericPropertyValue<DataType> implements PropertyHolder {

	private Class persistentType;
	private DataType value;
	
	public GenericPropertyValue() {	
	}
	
	public GenericPropertyValue(Class persistentClass) {
		this.persistentType = persistentClass;
	}
	
	/**
	 * @return Returns the persistentType.
	 */
	public Class getPersistentType() {
		return persistentType;
	}

	/**
	 * @param persistentType The persistentType to set.
	 */
	public void setPersistentType(Class persistentType) {
		this.persistentType = persistentType;
	}

	public DataType getValue() {
		return value;
	}
	
	public void setValue(DataType value) {
		this.value = value;
	}

	
}
