/**
 * The contents of this file are subject to the Rapid Transform Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.rapidtransform.com/license.html
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.core.util;

/**
 * This clas provides convenience method for the creating a equals() method for custom objects.
 * 
 * @author S. Werner
 */
public class EqualsUtil {
	
	/**
	 * Equal method for boolean.
	 */
	static public boolean areEqual(boolean aThis, boolean aThat) {
		return aThis == aThat;
	}

	/**
	 * Equal method for char.
	 */
	static public boolean areEqual(char aThis, char aThat) {
		return aThis == aThat;
	}

	/**
	 * Equal method for long, int, short, and byte
	 */
	static public boolean areEqual(long aThis, long aThat) {
		return aThis == aThat;
	}
	
	/**
	 * Equals method for float
	 */
	static public boolean areEqual(float aThis, float aThat) {
		return Float.floatToIntBits(aThis) == Float.floatToIntBits(aThat);
	}
	
	/**
	 * Equals method for double
	 */
	static public boolean areEqual(double aThis, double aThat) {
		return Double.doubleToLongBits(aThis) == Double.doubleToLongBits(aThat);
	}

	/**
	  * Equals method for all objects.  Possible null objects.
	  * Includes type-safe enumerations and collections, but does not include arrays. See class comment.
	  */
	static public boolean areEqual(Object aThis, Object aThat) {
		return aThis == null ? aThat == null : aThis.equals(aThat);
	}

}
