/**
 * The contents of this file are subject to the Rapid Transform Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.rapidtransform.com/license.html
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.part.dao.hibernate;

import java.sql.SQLException;
import java.util.Collection;
import java.util.List;

import org.hibernate.HibernateException;
import org.hibernate.Query;
import org.hibernate.Session;
import org.springframework.dao.DataAccessException;
import org.springframework.orm.hibernate3.HibernateCallback;

import com.rapidtransform.core.dao.hibernate.GenericDAOHibernate;
import com.rapidtransform.core.model.namespace.QName;
import com.rapidtransform.doc.model.Document;
import com.rapidtransform.part.dao.ItemVersionDAO;
import com.rapidtransform.part.model.ItemVersion;
import com.rapidtransform.product.model.Product;
import com.rapidtransform.spec.model.Specification;

/**
 * @author S. Werner
 *
 */
public class ItemVersionDAOHibernate extends GenericDAOHibernate<ItemVersion, Long> implements
		ItemVersionDAO {

	public ItemVersionDAOHibernate() {
		super(ItemVersion.class);
	}
	
	@SuppressWarnings("unchecked")
	public Collection<Specification> getSpecifications(final QName relationQname, final String itemId) throws DataAccessException {
		return (List<Specification>)getHibernateTemplate().execute(new HibernateCallback() {
			public Object doInHibernate(Session session) throws HibernateException, SQLException {
				Query q = session.createQuery("select target " +
						"from ItemSpecRelation as relation " +
						"join relation.target as target " +
						"where relation.metaTypeName=:relationType and " +
						"relation.source.id=:sourceId");
				q.setParameter("relationType", relationQname);
				q.setParameter("sourceId", Long.valueOf(itemId));
				return q.list();
			}
		});
	}

	@SuppressWarnings("unchecked")
	public Collection<Document> getDocuments(final QName relationQname, final String itemId) throws DataAccessException {
		return (List<Document>)getHibernateTemplate().execute(new HibernateCallback() {
			public Object doInHibernate(Session session) throws HibernateException, SQLException {
				Query q = session.createQuery("select target " +
						"from ItemDocRelation as relation " +
						"join relation.target as target " +
						"where relation.metaTypeName=:relationType and " +
						"relation.source.id=:sourceId");
				q.setParameter("relationType", relationQname);
				q.setParameter("sourceId", Long.valueOf(itemId));
				return q.list();
			}
		});	
	}

	@SuppressWarnings("unchecked")
	public Collection<ItemVersion> getRelatedItems(final QName relationQname, final String itemId) throws DataAccessException {
		return (List<ItemVersion>)getHibernateTemplate().execute(new HibernateCallback() {
			public Object doInHibernate(Session session) throws HibernateException, SQLException {
				Query q = session.createQuery("select target " +
						"from ItemItemRelation as relation " +
						"join relation.target as target " +
						"where relation.metaTypeName=:relationType and " +
						"relation.source.id=:sourceId");
				q.setParameter("relationType", relationQname);
				q.setParameter("sourceId", Long.valueOf(itemId));
				return q.list();
			}
		});	
	}

	@SuppressWarnings("unchecked")
	public Collection<Product> getProducts(final QName relationQname, final String itemId) throws DataAccessException {
		return (List<Product>)getHibernateTemplate().execute(new HibernateCallback() {
			public Object doInHibernate(Session session) throws HibernateException, SQLException {
				Query q = session.createQuery("select target " +
						"from ItemProductRelation as relation " +
						"join relation.target as target " +
						"where relation.metaTypeName=:relationType and " +
						"relation.source.id=:sourceId");
				q.setParameter("relationType", relationQname);
				q.setParameter("sourceId", Long.valueOf(itemId));
				return q.list();
			}
		});
	}

}
