/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.part.dao.hibernate;

import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.orm.hibernate3.support.HibernateDaoSupport;

import com.rapidtransform.core.dao.hibernate.GenericDAOHibernate;
import com.rapidtransform.part.dao.PartDAO;
import com.rapidtransform.part.model.Part;

/**
 * This class defines the Hibernate data access code for Part objects.  Methods in this class
 * define how Part data can be accessed, updated, and removed. 
 * 
 * @author Steve
 *
 */
public class PartDAOHibernate extends GenericDAOHibernate<Part, Long> implements PartDAO {
	private Log log = LogFactory.getLog(PartDAOHibernate.class);
	
	public PartDAOHibernate() {
		super(Part.class);
	}
	
	/* (non-Javadoc)
	 * @see com.rapidtransform.dao.PartDAO#getPart(java.lang.Long)
	 */
	public Part getPart(Long partId) {
		return (Part) getHibernateTemplate().get(Part.class, partId);
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.dao.PartDAO#getParts()
	 */
	public List getParts() {
		return getHibernateTemplate().find("from Part");
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.dao.PartDAO#savePart(com.rapidtransform.model.Part)
	 */
	public void savePart(Part part) {
		getHibernateTemplate().saveOrUpdate(part);

	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.dao.PartDAO#removePart(java.lang.Long)
	 */
	public void removePart(Long partId) {
		Part part = getPart(partId);
		getHibernateTemplate().delete(part);
		if (log.isDebugEnabled()) log.debug("Part "+partId+" was removed");
	}

}
