/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.part.model;

import java.util.Collection;
import java.util.Set;

import com.rapidtransform.classification.model.Classified;
import com.rapidtransform.core.model.VersionControlled;
import com.rapidtransform.doc.model.Document;
import com.rapidtransform.org.model.Alias;
import com.rapidtransform.org.model.Approvable;
import com.rapidtransform.org.model.OrganizationElement;
import com.rapidtransform.org.model.OrganizationalData;
import com.rapidtransform.product.model.ProductConstituent;
import com.rapidtransform.spec.model.Configuration;
import com.rapidtransform.spec.model.Effective;
import com.rapidtransform.spec.model.ManufacturingConfig;

/**
 * An ItemInstance represents the occurrence of an Item in a product structure that is
 * defined either by an ItemView or a ProductIdentification.
 * 
 * @author Steve
 *
 */
public abstract class ItemInstance extends VersionControlled 
	implements ItemInformation, ProductConstituent, Classified, Approvable, OrganizationElement, OrganizationalData, Effective {
	
	private Set<ItemInstanceRelation> relations;
	private String description;
	
	private ItemView itemView;
	
	// controls the config for manufacturing this item
	private Set<ManufacturingConfig> manufacturingConfigs;
	
	// controls the configuration for this item's usage
	private Set<Configuration> configs;
	
	private Set<Alias> aliases;
	private Set<Document> documents;

	// TODO association to custom ItemInstance properties -- vertical specific?	
	
	/**
	 * @return Returns the aliases.
	 */
	public Collection<Alias> getAliases() {
		return aliases;
	}
	/**
	 * @param aliases The aliases to set.
	 */
	public void setAliases(Set<Alias> aliases) {
		this.aliases = aliases;
	}
	/**
	 * @return Returns the config.
	 */
	public Collection<Configuration> getConfigs() {
		return configs;
	}
	/**
	 * @param config The config to set.
	 */
	public void setConfigs(Set<Configuration> configs) {
		this.configs = configs;
	}
	/**
	 * @return Returns the description.
	 */
	public String getDescription() {
		return description;
	}
	/**
	 * @param description The description to set.
	 */
	public void setDescription(String description) {
		this.description = description;
	}
	/**
	 * @return Returns the documents.
	 */
	public Collection<Document> getDocuments() {
		return documents;
	}
	/**
	 * @param documents The documents to set.
	 */
	public void setDocuments(Set<Document> documents) {
		this.documents = documents;
	}
	/**
	 * @return Returns the manufacturingConfig.
	 */
	public Collection<ManufacturingConfig> getManufacturingConfigs() {
		return manufacturingConfigs;
	}
	/**
	 * @param manufacturingConfig The manufacturingConfig to set.
	 */
	public void setManufacturingConfig(Set<ManufacturingConfig> manufacturingConfisg) {
		this.manufacturingConfigs = manufacturingConfigs;
	}
	/**
	 * @return Returns the relations.
	 */
	public Collection<ItemInstanceRelation> getRelations() {
		return relations;
	}
	/**
	 * @param relations The relations to set.
	 */
	public void setRelations(Set<ItemInstanceRelation> relations) {
		this.relations = relations;
	}
	/**
	 * @param manufacturingConfigs The manufacturingConfigs to set.
	 */
	public void setManufacturingConfigs(
			Set<ManufacturingConfig> manufacturingConfigs) {
		this.manufacturingConfigs = manufacturingConfigs;
	}
	/**
	 * @return Returns the itemView.
	 */
	public ItemView getItemView() {
		return itemView;
	}
	/**
	 * @param itemView The itemView to set.
	 */
	public void setItemView(ItemView itemView) {
		this.itemView = itemView;
	}
	
}
