/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.part.model;

/**
 * A QuantifiedInstance is an object with a specified number quantity for this item in the
 * product structure.  The QuantifiedInstance is defined either as an ItemView or a Product.
 * 
 * @author Steve Werner
 *
 */
public class QuantifiedInstance extends ItemInstance {
	private Integer quantity;
	
	/**
	 * default constructor
	 */
	public QuantifiedInstance() {
	}
	
	/**
	 * Construct a QuantifiedInstance with the given quantity and ItemVersion.
	 * @param forView The parent ItemView of this instance
	 * @param quantity
	 */
	public QuantifiedInstance(ItemView forView, Integer quantity) {
		this.setItemView(forView);
		this.quantity = quantity;
	}

	/**
	 * @return Returns the quantity.
	 */
	public Integer getQuantity() {
		return quantity;
	}

	/**
	 * @param quantity The quantity to set.
	 */
	public void setQuantity(Integer quantity) {
		this.quantity = quantity;
	}
	
}
