/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.part.model;

import com.rapidtransform.product.model.Quantity;
import com.rapidtransform.product.model.UnitOfMeasure;

/**
 * The SelectedInstance is an item on a product structure whose quantity depends on the selection control
 * constraints (@see SelectionControl).  A SelectedInstance can either be an ItemView or a Product.
 * 
 * @author S. Werner
 *
 */
public class SelectedInstance extends ItemInstance {
	private String selectionControl;
	private Quantity quantity;
	
	/**
	 * default constructor
	 */
	public SelectedInstance() {
		
	}
	
	/**
	 * Creates an instance of the specified version.
	 * @param forView The parent ItemView of this instance
	 */
	public SelectedInstance(ItemView forView) {
		this.setItemView(forView);
	}
	
	
	/**
	 * @return Returns the quantity.
	 */
	public Quantity getQuantity() {
		return quantity;
	}
	/**
	 * @param quantity The quantity to set.
	 */
	public void setQuantity(Quantity quantity) {
		this.quantity = quantity;
	}
	/**
	 * @return Returns the selectionControl.
	 */
	public String getSelectionControl() {
		return selectionControl;
	}
	/**
	 * @param selectionControl The selectionControl to set.
	 */
	public void setSelectionControl(String selectionControl) {
		this.selectionControl = selectionControl;
	}

	
}
