/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.part.model;

/**
 * This class identifies a single item on an assembly that reuses partial decompositions.
 * 
 * To be exact, the related instance is the object to be identified.  The upperUsage instance
 * is the ItemInstance in which the related instance is used.  The assembly specifies the assembly in 
 * which the related instance is used.
 * 
 * @author S. Werner
 *
 */
public class SpecifiedInstance extends ItemInstance {
	private Assembly assembly;
	private ItemInstance related;
	private ItemInstance upperUsage;
	
	public SpecifiedInstance() {
		
	}
	
	/**
	 * Create an instance for the specified IntemVersion.
	 * @param forView The parent ItemView of this instance
	 */
	public SpecifiedInstance(ItemView forView) {
		this.setItemView(forView);
	}
	
	/**
	 * @return Returns the assembly.
	 */
	public Assembly getAssembly() {
		return assembly;
	}
	/**
	 * @param assembly The assembly to set.
	 */
	public void setAssembly(Assembly assembly) {
		this.assembly = assembly;
	}
	/**
	 * @return Returns the related.
	 */
	public ItemInstance getRelated() {
		return related;
	}
	/**
	 * @param related The related to set.
	 */
	public void setRelated(ItemInstance related) {
		this.related = related;
	}
	/**
	 * @return Returns the upperUsage.
	 */
	public ItemInstance getUpperUsage() {
		return upperUsage;
	}
	/**
	 * @param upperUsage The upperUsage to set.
	 */
	public void setUpperUsage(ItemInstance upperUsage) {
		this.upperUsage = upperUsage;
	}
	
}
