/**
 * The contents of this file are subject to the Rapid Transform Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.rapidtransform.com/license.html
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.part.service;

import java.util.List;

import org.springframework.dao.DataAccessException;

import com.rapidtransform.core.ConveloException;
import com.rapidtransform.core.service.CRUDService;
import com.rapidtransform.core.service.MetaCRUDService;
import com.rapidtransform.core.service.Service;
import com.rapidtransform.doc.service.DocumentedService;
import com.rapidtransform.part.model.Assembly;
import com.rapidtransform.part.model.CollectionView;
import com.rapidtransform.part.model.Item;
import com.rapidtransform.part.model.ItemInstance;
import com.rapidtransform.part.model.ItemVersion;
import com.rapidtransform.part.model.ItemView;
import com.rapidtransform.part.model.QuantifiedInstance;
import com.rapidtransform.part.model.SelectedInstance;
import com.rapidtransform.part.model.SingleInstance;
import com.rapidtransform.part.model.SpecifiedInstance;
import com.rapidtransform.spec.service.SpecifiedService;

/**
 * This service provides methods for finding Items and Item subcomponents as well as
 * CRUD services for these objects.
 * 
 * The methods contain logic for incorporating business rules and workflow processes.
 * 
 * @author S. Werner
 *
 */
public interface ItemService extends MetaCRUDService<ItemVersion>, SpecifiedService<ItemVersion>, DocumentedService<ItemVersion> {
	
	public Item findItem(String itemId) throws ConveloException, DataAccessException;
	public List findItems(Integer resultsPerPage) throws ConveloException, DataAccessException;
	public ItemVersion revise(Item item) throws ConveloException;
	
	public ItemView saveItemView(ItemView itemView) throws ConveloException, DataAccessException;
	public Assembly saveAssembly(Assembly assembly) throws ConveloException, DataAccessException;
	public CollectionView saveCollectionView(CollectionView collectionView) throws ConveloException, DataAccessException;
	
	public ItemInstance saveItemInstance(ItemInstance itemInstance) throws ConveloException, DataAccessException;
	public SingleInstance saveSingleInstance(SingleInstance singleInstance) throws ConveloException, DataAccessException;
	public QuantifiedInstance saveQuantifiedInstance(QuantifiedInstance quantifiedInstance) throws ConveloException, DataAccessException;
	public SelectedInstance saveSelectedInstance(SelectedInstance selectedInstance) throws ConveloException, DataAccessException;
	public SpecifiedInstance saveSpecifiedInstance(SpecifiedInstance specifiedInstance) throws ConveloException, DataAccessException;
	
}
