/**
 * The contents of this file are subject to the Rapid Transform Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.rapidtransform.com/license.html
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.product.dao.hibernate;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import org.hibernate.FetchMode;
import org.hibernate.HibernateException;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.criterion.Restrictions;
import org.springframework.dao.DataAccessException;
import org.springframework.orm.hibernate3.HibernateCallback;

import com.rapidtransform.core.dao.hibernate.GenericDAOHibernate;
import com.rapidtransform.product.dao.ProductClassDAO;
import com.rapidtransform.product.model.ProductClass;
import com.rapidtransform.spec.model.ClassSpecificationAssociation;
import com.rapidtransform.spec.model.Specification;

/**
 * @author S. Werner
 *
 */
public class ProductClassDAOHibernate extends GenericDAOHibernate<ProductClass, Long> implements
		ProductClassDAO {
	
	public ProductClassDAOHibernate() {
		super(ProductClass.class);
	}

	@SuppressWarnings("unchecked")
	public List<Specification> getSpecifications(final ProductClass prodClass) throws DataAccessException {
		List<Specification> specs = new ArrayList<Specification>();
		List<ClassSpecificationAssociation> csaList = (List<ClassSpecificationAssociation>)getHibernateTemplate().execute(new HibernateCallback() {
			public Object doInHibernate(Session session) throws HibernateException, SQLException {
				return (List<ClassSpecificationAssociation>)session.createCriteria(ClassSpecificationAssociation.class)
					.add( Restrictions.eq("parentId", prodClass.getId()) )
					.setFetchMode("specification", FetchMode.JOIN)
					.list();
			}
		});
		for (ClassSpecificationAssociation csa : csaList) {
			specs.add(csa.getSpecification());
		}
		return specs;
	}
	
	
}
