/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 with a permitted attribution clause (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.rapidtransform.com/legal/license.txt
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Convelo Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005,2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 */
package com.rapidtransform.product.dao.hibernate;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.hibernate.FetchMode;
import org.hibernate.HibernateException;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.criterion.Restrictions;
import org.springframework.dao.DataAccessException;
import org.springframework.orm.hibernate3.HibernateCallback;

import com.rapidtransform.core.dao.hibernate.GenericDAOHibernate;
import com.rapidtransform.core.model.Relation;
import com.rapidtransform.core.model.namespace.QName;
import com.rapidtransform.doc.model.Document;
import com.rapidtransform.part.model.ItemVersion;
import com.rapidtransform.product.dao.ProductDAO;
import com.rapidtransform.product.model.Product;
import com.rapidtransform.product.model.ProductSpecRelation;
import com.rapidtransform.spec.model.ClassSpecificationAssociation;
import com.rapidtransform.spec.model.Specification;

/**
 * @author Steve Werner
 *
 */
public class ProductDAOHibernate extends GenericDAOHibernate<Product, Long> implements ProductDAO {
	
	public ProductDAOHibernate() {
		super(Product.class);
	}

	@SuppressWarnings("unchecked")
	public Collection<Specification> getSpecifications(final QName relationQname, final String productId) throws DataAccessException {
		return (List<Specification>)getHibernateTemplate().execute(new HibernateCallback() {
			public Object doInHibernate(Session session) throws HibernateException, SQLException {
				Query q = session.createQuery("select target " +
						"from ProductSpecRelation as relation " +
						"join relation.target as target " +
						"where relation.metaTypeName=:relationType and " +
						"relation.source.id=:sourceId");
				q.setParameter("relationType", relationQname);
				q.setParameter("sourceId", Long.valueOf(productId));
				return q.list();
			}
		});
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.product.dao.ProductDAO#getDocuments(com.rapidtransform.core.model.namespace.QName, java.lang.String)
	 */
	@SuppressWarnings("unchecked")
	public Collection<Document> getDocuments(final QName relationQname, final String productId) throws DataAccessException {
		return (List<Document>)getHibernateTemplate().execute(new HibernateCallback() {
			public Object doInHibernate(Session session) throws HibernateException, SQLException {
				Query q = session.createQuery("select target " +
						"from ProductDocRelation as relation " +
						"join relation.target as target " +
						"where relation.metaTypeName=:relationType and " +
						"relation.source.id=:sourceId");
				q.setParameter("relationType", relationQname);
				q.setParameter("sourceId", Long.valueOf(productId));
				return q.list();
			}
		});	
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.product.dao.ProductDAO#getItems(com.rapidtransform.core.model.namespace.QName, java.lang.String)
	 */
	@SuppressWarnings("unchecked")
	public Collection<ItemVersion> getItems(final QName relationQname, final String productId) throws DataAccessException {
		return (List<ItemVersion>)getHibernateTemplate().execute(new HibernateCallback() {
			public Object doInHibernate(Session session) throws HibernateException, SQLException {
				Query q = session.createQuery("select target " +
						"from ProductItemRelation as relation " +
						"join relation.target as target " +
						"where relation.metaTypeName=:relationType and " +
						"relation.source.id=:sourceId");
				q.setParameter("relationType", relationQname);
				q.setParameter("sourceId", Long.valueOf(productId));
				return q.list();
			}
		});	
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.product.dao.ProductDAO#getRelatedProducts(com.rapidtransform.core.model.namespace.QName, java.lang.String)
	 */
	@SuppressWarnings("unchecked")
	public Collection<Product> getRelatedProducts(final QName relationQname, final String productId) throws DataAccessException {
		return (List<Product>)getHibernateTemplate().execute(new HibernateCallback() {
			public Object doInHibernate(Session session) throws HibernateException, SQLException {
				Query q = session.createQuery("select target " +
						"from ProductProductRelation as relation " +
						"join relation.target as target " +
						"where relation.metaTypeName=:relationType and " +
						"relation.source.id=:sourceId");
				q.setParameter("relationType", relationQname);
				q.setParameter("sourceId", Long.valueOf(productId));
				return q.list();
			}
		});
	}
}
