/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.product.model;

import java.util.Set;

/**
 * A final solution is a set of additional sensual characteristics that can be applied to an item instance
 * that represents a neutral part to finalize it's definition.
 *  
 * TODO move finalsolution to part package?
 * 
 * @author S. Werner
 *
 */
public class FinalSolution extends AlternateSolution {
	// TODO define final status - are inwork, complete, dropped valid?  this is not defined in the spec.
	private enum Status {
		INWORK,
		COMPLETE,
		DROPPED;
	}
	
	/**
	 * Status specifies the completion level for defining a final solution from a neutral part
	 */
	private Status status;
	
	/**
	 * The definition is the specification for the final solution, or is the final solution itself (in the
	 * case where the definition is an ItemView or PhysicalInstance).
	 */
	private Set<FinalDefinition> definition;

	/**
	 * @return Returns the definition.
	 */
	public Set<FinalDefinition> getDefinition() {
		return definition;
	}

	/**
	 * @param definition The definition to set.
	 */
	public void setDefinition(Set<FinalDefinition> definition) {
		this.definition = definition;
	}

	/**
	 * @return Returns the status.
	 */
	public Status getStatus() {
		return status;
	}

	/**
	 * @param status The status to set.
	 */
	public void setStatus(Status status) {
		this.status = status;
	}
	
	
}
