/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.product.model;

import java.util.Set;

import com.rapidtransform.core.model.AbstractBaseModel;
import com.rapidtransform.doc.model.Document;
import com.rapidtransform.org.model.Alias;
import com.rapidtransform.org.model.Approvable;
import com.rapidtransform.org.model.OrganizationElement;
import com.rapidtransform.org.model.OrganizationalData;
import com.rapidtransform.part.model.ItemInformation;

/**
 * A PhysicalInstance is the definition of a physically realized object which may be identified
 * by a serial number and lot id.
 * 
 * @author S. Werner
 *
 */
public class PhysicalInstance extends AbstractBaseModel 
	implements ItemInformation, Approvable, OrganizationElement, OrganizationalData, FinalDefinition {
	
	private String serialNumber;
	private String lotId;
	private String description;
	
	/**
	 * The inventory number identifies an item in a detailed list of articles for a person
	 * or organization.
	 */
	private String inventoryNumber;
	
	private Set<PhysicalInstanceTestResult> testResults;
	private Set<PhysicalAssemblyRelation> physicalAssemblies;
	private Set<Document> documents;
	private Set<Alias> aliases;
	
	/**
	 * The reference to an object that is this physical instance defines
	 */
	private PhysicalInstanceDefinition realizationOf;

	/**
	 * @return Returns the aliases.
	 */
	public Set<Alias> getAliases() {
		return aliases;
	}

	/**
	 * @param aliases The aliases to set.
	 */
	public void setAliases(Set<Alias> aliases) {
		this.aliases = aliases;
	}

	/**
	 * @return Returns the description.
	 */
	public String getDescription() {
		return description;
	}

	/**
	 * @param description The description to set.
	 */
	public void setDescription(String description) {
		this.description = description;
	}

	/**
	 * @return Returns the documents.
	 */
	public Set<Document> getDocuments() {
		return documents;
	}

	/**
	 * @param documents The documents to set.
	 */
	public void setDocuments(Set<Document> documents) {
		this.documents = documents;
	}

	/**
	 * @return Returns the inventoryNumber.
	 */
	public String getInventoryNumber() {
		return inventoryNumber;
	}

	/**
	 * @param inventoryNumber The inventoryNumber to set.
	 */
	public void setInventoryNumber(String inventoryNumber) {
		this.inventoryNumber = inventoryNumber;
	}

	/**
	 * @return Returns the lotId.
	 */
	public String getLotId() {
		return lotId;
	}

	/**
	 * @param lotId The lotId to set.
	 */
	public void setLotId(String lotId) {
		this.lotId = lotId;
	}

	/**
	 * @return Returns the physicalAssemblies.
	 */
	public Set<PhysicalAssemblyRelation> getPhysicalAssemblies() {
		return physicalAssemblies;
	}

	/**
	 * @param physicalAssemblies The physicalAssemblies to set.
	 */
	public void setPhysicalAssemblies(
			Set<PhysicalAssemblyRelation> physicalAssemblies) {
		this.physicalAssemblies = physicalAssemblies;
	}

	/**
	 * @return Returns the realizationOf.
	 */
	public PhysicalInstanceDefinition getRealizationOf() {
		return realizationOf;
	}

	/**
	 * @param realizationOf The realizationOf to set.
	 */
	public void setRealizationOf(PhysicalInstanceDefinition realizationOf) {
		this.realizationOf = realizationOf;
	}

	/**
	 * @return Returns the serialNumber.
	 */
	public String getSerialNumber() {
		return serialNumber;
	}

	/**
	 * @param serialNumber The serialNumber to set.
	 */
	public void setSerialNumber(String serialNumber) {
		this.serialNumber = serialNumber;
	}

	/**
	 * @return Returns the testResults.
	 */
	public Set<PhysicalInstanceTestResult> getTestResults() {
		return testResults;
	}

	/**
	 * @param testResults The testResults to set.
	 */
	public void setTestResults(Set<PhysicalInstanceTestResult> testResults) {
		this.testResults = testResults;
	}
	
	
}
