/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.product.model;

import java.util.Set;

import com.rapidtransform.classification.model.Classified;
import com.rapidtransform.core.model.Relation;
import com.rapidtransform.core.model.VersionControlled;
import com.rapidtransform.core.util.EqualsUtil;
import com.rapidtransform.doc.model.Documented;
import com.rapidtransform.org.model.Alias;
import com.rapidtransform.org.model.Approvable;
import com.rapidtransform.org.model.OrganizationElement;
import com.rapidtransform.org.model.OrganizationalData;
import com.rapidtransform.spec.model.DesignConstraintAssociation;
import com.rapidtransform.spec.model.Effective;
import com.rapidtransform.spec.model.Specified;

/**
 * A product is an object with the capability to be realized by, decomposed into or 
 * specialized by a set of ProductConstituent objects in a functional, logical, or physical
 * manner.  A product represents a manufacturable object or the design for one.
 * 
 * @author S. Werner
 *
 */
public class Product extends VersionControlled 
	implements Complex, ProductConstituent, Classified, Approvable, OrganizationElement, OrganizationalData, 
				Effective, PhysicalInstanceDefinition, Specified, Documented {

	private String productId;
	
	private ProductClass productClass;
	private Set<Relation> specs;
	private Set<Relation> documents;
	
	private Set<ProductStructureRelation> productStructureRelations;
	private Set<DesignConstraintAssociation> designContraintAssociations;
	private Set<ComplexProductRelation> complexProductRelations;
	private Set<Alias> aliases;
	
	public Product() {
	}
	
	public Set<Alias> getAliases() {
		return aliases;
	}
	public void setAliases(Set<Alias> aliases) {
		this.aliases = aliases;
	}
	public Set<ComplexProductRelation> getComplexProductRelations() {
		return complexProductRelations;
	}
	public void setComplexProductRelations(
			Set<ComplexProductRelation> complexProductRelations) {
		this.complexProductRelations = complexProductRelations;
	}
	public Set<DesignConstraintAssociation> getDesignContraintAssociations() {
		return designContraintAssociations;
	}
	public void setDesignContraintAssociations(
			Set<DesignConstraintAssociation> designContraintAssociations) {
		this.designContraintAssociations = designContraintAssociations;
	}
	public ProductClass getProductClass() {
		return productClass;
	}
	public void setProductClass(ProductClass productClass) {
		this.productClass = productClass;
	}
	public Set<ProductStructureRelation> getProductStructureRelations() {
		return productStructureRelations;
	}
	public void setProductStructureRelations(
			Set<ProductStructureRelation> productStructureRelations) {
		this.productStructureRelations = productStructureRelations;
	}

	/**
	 * @return Returns the specs.
	 */
	public Set<Relation> getSpecs() {
		return specs;
	}

	/**
	 * @param specs The specs to set.
	 */
	public void setSpecs(Set<Relation> specs) {
		this.specs = specs;
	}
	
	/**
	 * @return Returns the documents.
	 */
	public Set<Relation> getDocuments() {
		return documents;
	}

	/**
	 * @param documents The documents to set.
	 */
	public void setDocuments(Set<Relation> documents) {
		this.documents = documents;
	}

	public String getProductId() {
		return productId;
	}
	public void setProductId(String productId) {
		this.productId = productId;
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.core.model.AbstractBaseModel#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object other) {
		return EqualsUtil.areEqual(this.getUuid(), ((Product)other).getUuid());
	}
	
	/* (non-Javadoc)
	 * @see com.rapidtransform.core.model.AbstractBaseModel#hashCode()
	 */
	@Override
	public int hashCode() {
		return this.getUuid().hashCode();
	}
}
