/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.product.model;

import java.util.Date;
import java.util.Set;

import com.rapidtransform.admin.model.User;
import com.rapidtransform.classification.model.Classified;
import com.rapidtransform.core.model.AbstractBaseModel;
import com.rapidtransform.core.model.VersionControlled;
import com.rapidtransform.doc.model.Document;
import com.rapidtransform.org.model.Alias;
import com.rapidtransform.org.model.Approvable;
import com.rapidtransform.org.model.OrganizationElement;
import com.rapidtransform.org.model.OrganizationalData;
import com.rapidtransform.spec.model.ClassCategoryAssociation;
import com.rapidtransform.spec.model.ClassConditionAssociation;
import com.rapidtransform.spec.model.ClassInclusionAssociation;
import com.rapidtransform.spec.model.ClassSpecificationAssociation;
import com.rapidtransform.spec.model.ClassStructureRelation;
import com.rapidtransform.spec.model.Effective;

/**
 * The ProductClass is a set of similar products to be offered on the market.  Related ProductClass objects
 * do not inherit or share any characteristics from each other.
 * 
 * @author S. Werner
 *
 */
public class ProductClass extends VersionControlled 
	implements Classified, Approvable, OrganizationElement, OrganizationalData, Effective {
	private String classId;
	private String versionId;
	/**
	 * TODO The levelType specifies the level or category of the ProductClass in a hierarchical structure
	 * of ProductClass objects.  This attribute shall only be used if the levelType is specified in 
	 * the context of the unit of functionality 'specification_control' UoF S7.
	 */
	private String levelType;
	
	private Set<Product> products;
	private String description;
	private String name;
	private Date createdDate;
	private Date modifiedDate;
	private User createdBy;
	private User modifiedBy;
	private Set<ClassStructureRelation> classStructures;
	private Set<ClassSpecificationAssociation> classSpecs;
	private Set<ClassInclusionAssociation> classInclusions;
	private Set<ClassConditionAssociation> classConditions;
	private Set<ClassCategoryAssociation> classCategories;
	private Set<Alias> aliases;
	public Set<Alias> getAliases() {
		return aliases;
	}
	public void setAliases(Set<Alias> aliases) {
		this.aliases = aliases;
	}
	public Set<ClassCategoryAssociation> getClassCategories() {
		return classCategories;
	}
	public void setClassCategories(Set<ClassCategoryAssociation> classCategories) {
		this.classCategories = classCategories;
	}
	public Set<ClassConditionAssociation> getClassConditions() {
		return classConditions;
	}
	public void setClassConditions(Set<ClassConditionAssociation> classConditions) {
		this.classConditions = classConditions;
	}
	public String getClassId() {
		return classId;
	}
	public void setClassId(String classId) {
		this.classId = classId;
	}
	public Set<ClassInclusionAssociation> getClassInclusions() {
		return classInclusions;
	}
	public void setClassInclusions(Set<ClassInclusionAssociation> classInclusions) {
		this.classInclusions = classInclusions;
	}
	public Set<ClassSpecificationAssociation> getClassSpecs() {
		return classSpecs;
	}
	public void setClassSpecs(Set<ClassSpecificationAssociation> classSpecs) {
		this.classSpecs = classSpecs;
	}
	public Set<ClassStructureRelation> getClassStructures() {
		return classStructures;
	}
	public void setClassStructures(Set<ClassStructureRelation> classStructures) {
		this.classStructures = classStructures;
	}
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	public String getLevelType() {
		return levelType;
	}
	public void setLevelType(String levelType) {
		this.levelType = levelType;
	}
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public Set<Product> getProducts() {
		return products;
	}
	public void setProducts(Set<Product> products) {
		this.products = products;
	}
	public String getVersionId() {
		return versionId;
	}
	public void setVersionId(String versionId) {
		this.versionId = versionId;
	}
	public User getCreatedBy() {
		return createdBy;
	}
	public void setCreatedBy(User createdBy) {
		this.createdBy = createdBy;
	}
	public Date getCreatedDate() {
		return createdDate;
	}
	public void setCreatedDate(Date createdDate) {
		this.createdDate = createdDate;
	}
	public User getModifiedBy() {
		return modifiedBy;
	}
	public void setModifiedBy(User modifiedBy) {
		this.modifiedBy = modifiedBy;
	}
	public Date getModifiedDate() {
		return modifiedDate;
	}
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}
	
}
