/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.product.model;

import java.util.Set;

import com.rapidtransform.core.model.AbstractBaseModel;
import com.rapidtransform.part.model.ApplicationContext;
import com.rapidtransform.part.model.ItemInformation;
import com.rapidtransform.spec.model.ClassCategoryAssociation;
import com.rapidtransform.spec.model.Configuration;

/**
 * A ProductComponent is an element in a conceptual product structure.
 * 
 * @author S. Werner
 *
 */
public class ProductComponent extends Product 
	implements ItemInformation, ProductFunctionComponent {
	
	/**
	 * This attribute specifies that this ProductComponent or AlternateSolutions in the form
	 * of ItemInstances is required on the product structure.
	 */
	private Boolean instanceRequired;
	
	private String description;
	private String name;
	private Set<Configuration> configuration;
	private Set<ComponentPlacement> placement;
	private Set<ApplicationContext> relevantFor;
	private Set<ClassCategoryAssociation> influencedBy;
	/**
	 * @return Returns the configuration.
	 */
	public Set<Configuration> getConfiguration() {
		return configuration;
	}
	/**
	 * @param configuration The configuration to set.
	 */
	public void setConfiguration(Set<Configuration> configuration) {
		this.configuration = configuration;
	}
	/**
	 * @return Returns the description.
	 */
	public String getDescription() {
		return description;
	}
	/**
	 * @param description The description to set.
	 */
	public void setDescription(String description) {
		this.description = description;
	}
	/**
	 * @return Returns the influencedBy.
	 */
	public Set<ClassCategoryAssociation> getInfluencedBy() {
		return influencedBy;
	}
	/**
	 * @param influencedBy The influencedBy to set.
	 */
	public void setInfluencedBy(Set<ClassCategoryAssociation> influencedBy) {
		this.influencedBy = influencedBy;
	}
	/**
	 * @return Returns the instanceRequired.
	 */
	public Boolean getInstanceRequired() {
		return instanceRequired;
	}
	/**
	 * @param instanceRequired The instanceRequired to set.
	 */
	public void setInstanceRequired(Boolean instanceRequired) {
		this.instanceRequired = instanceRequired;
	}
	/**
	 * @return Returns the name.
	 */
	public String getName() {
		return name;
	}
	/**
	 * @param name The name to set.
	 */
	public void setName(String name) {
		this.name = name;
	}
	/**
	 * @return Returns the placement.
	 */
	public Set<ComponentPlacement> getPlacement() {
		return placement;
	}
	/**
	 * @param placement The placement to set.
	 */
	public void setPlacement(Set<ComponentPlacement> placement) {
		this.placement = placement;
	}
	/**
	 * @return Returns the relevantFor.
	 */
	public Set<ApplicationContext> getRelevantFor() {
		return relevantFor;
	}
	/**
	 * @param relevantFor The relevantFor to set.
	 */
	public void setRelevantFor(Set<ApplicationContext> relevantFor) {
		this.relevantFor = relevantFor;
	}
	
	
}
