/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.product.model;

import java.util.Set;

import com.rapidtransform.core.model.AbstractBaseModel;
import com.rapidtransform.doc.model.Document;
import com.rapidtransform.org.model.Approvable;
import com.rapidtransform.org.model.OrganizationElement;
import com.rapidtransform.org.model.OrganizationalData;
import com.rapidtransform.part.model.InstanceUsageContext;
import com.rapidtransform.part.model.ItemInstance;
import com.rapidtransform.spec.model.Effective;

/**
 * The ProductStructureRelation links a Product with it's ProductConstituents, where the consituent
 * is a functional, logical, or physical component or realization of the complex product.
 * 
 * @author S. Werner
 *
 */
public abstract class ProductStructureRelation extends AbstractBaseModel 
	implements InstanceUsageContext, Approvable, OrganizationElement, OrganizationalData, Effective {
	
	public enum RelationType {
		/**
		 * The related ProductConstituent is one or possibly many components of the relating Product
		 */
		DECOMPOSITION,
		
		/**
		 * The related ProductConstituent is part of the functional structure.  The relating complex product
		 * must be of type AlternateSolution or ProductComponent and the ProductConstituent must be a ProductFunction.
		 */
		FUNCTIONALITY,
		
		/**
		 * The product constituent is an occurence of the complex product.
		 */
		OCCURRENCE,
		
		/**
		 * The product constituent fulfills some or all the requirements for the complex product, and the
		 * constituent and complex products are of different types.
		 */
		REALIZATION,
		
		/**
		 * The product constituent fulfills the requirements for the complex product and they are of the same type.
		 */
		SPECIALIZATION;
	}
	private RelationType type;
	
	private String description;
	private Set<Document> documents;
	private Product relating;
	/**
	 * @return Returns the description.
	 */
	public String getDescription() {
		return description;
	}
	/**
	 * @param description The description to set.
	 */
	public void setDescription(String description) {
		this.description = description;
	}
	/**
	 * @return Returns the documents.
	 */
	public Set<Document> getDocuments() {
		return documents;
	}
	/**
	 * @param documents The documents to set.
	 */
	public void setDocuments(Set<Document> documents) {
		this.documents = documents;
	}

	/**
	 * @return Returns the relating.
	 */
	public Product getRelating() {
		return relating;
	}
	/**
	 * @param relating The relating to set.
	 */
	public void setRelating(Product relating) {
		this.relating = relating;
	}
	/**
	 * @return Returns the type.
	 */
	public RelationType getType() {
		return type;
	}
	/**
	 * @param type The type to set.
	 */
	public void setType(RelationType type) {
		this.type = type;
	}

}
