/**
 * The contents of this file are subject to the Rapid Transform Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.rapidtransform.com/license.html
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.product.model;

import com.rapidtransform.core.model.AbstractBaseModel;

/**
 * Quantity represents a value or range of values along with the Unit of Measure.
 * 
 * If range=true, then the upperLimit value must be set.  Otherwise, only the quantity
 * value is valid.
 * 
 * @author S. Werner
 */
public class Quantity extends AbstractBaseModel {
	private Integer quantity;
	private Integer upperLimit;
	private boolean range = false;
	private UnitOfMeasure uom;
	
	public Quantity() {	
	}
	
	/**
	 * constructor for a single value quantity.
	 * @param value
	 * @param uom
	 */
	public Quantity(Integer value, UnitOfMeasure uom) {
		this.quantity = value;
		this.uom = uom;
	}
	
	/**
	 * Constructor for a Range quantity.
	 * @param lowerLimit
	 * @param upperLimit
	 * @param uom
	 */
	public Quantity(Integer lowerLimit, Integer upperLimit, UnitOfMeasure uom) {
		this.quantity = lowerLimit;
		this.upperLimit = upperLimit;
		this.uom = uom;
		this.range = true;
	}
	
	/**
	 * @return Returns If this quantity is a range.
	 */
	public boolean isRange() {
		return range;
	}
	/**
	 * @param range The range to set.
	 */
	public void setRange(boolean range) {
		this.range = range;
	}
	
	/**
	 * @return Returns the uom.
	 */
	public UnitOfMeasure getUom() {
		return uom;
	}
	/**
	 * @param uom The uom to set.
	 */
	public void setUom(UnitOfMeasure uom) {
		this.uom = uom;
	}
	
	/**
	 * @return Returns the upperLimit.
	 */
	public Integer getUpperLimit() {
		return upperLimit;
	}
	/**
	 * Must be set if this Quantity is a range.
	 * 
	 * @param upperLimit The upperLimit to set.
	 */
	public void setUpperLimit(Integer upperLimit) {
		this.upperLimit = upperLimit;
	}
	
	/**
	 * The actual quantity value.  If range=true, then tihs will be the lower limit of the range.
	 * 
	 * @return Returns the quantity.
	 */
	public Integer getQuantity() {
		return quantity;
	}
	/**
	 * The actual quantity value.  If range=true, then this will be the lower limit of the range.
	 * 
	 * @param quantity The quantity to set.
	 */
	public void setQuantity(Integer quantity) {
		this.quantity = quantity;
	}
	

	
}
