/**
 * The contents of this file are subject to the Rapid Transform Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.rapidtransform.com/license.html
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.product.service.impl;

import java.util.Date;
import java.util.List;
import java.util.Set;

import org.springframework.transaction.annotation.Transactional;

import com.rapidtransform.core.service.impl.ServiceImpl;
import com.rapidtransform.product.dao.ProductClassDAO;
import com.rapidtransform.product.dao.ProductDAO;
import com.rapidtransform.product.model.Product;
import com.rapidtransform.product.model.ProductClass;
import com.rapidtransform.product.service.ProductDesignService;
import com.rapidtransform.product.service.ProductService;
import com.rapidtransform.spec.model.Specification;

/**
 * @author S. Werner
 *
 */
public class ProductDesignServiceImpl extends ServiceImpl implements
		ProductDesignService {
	
	private ProductClassDAO productClassDao;
	private ProductDAO productDao;

	public void setProductClassDao(ProductClassDAO productClassDao) {
		this.productClassDao = productClassDao;
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.product.service.ProductDesignService#createProductClass()
	 */
	public ProductClass createProductClass() {
		ProductClass pClass = new ProductClass();
		Date created = new Date();
		pClass.setCreatedDate(created);
		pClass.setCreatedBy(getSecurityService().getAuthenticatedUser());
		return pClass;
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.product.service.ProductDesignService#findAllProductClasses()
	 */
	public List<ProductClass> findAllProductClasses() {
		return productClassDao.findAll();
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.product.service.ProductDesignService#findProductClass(java.lang.String)
	 */
	public ProductClass findProductClass(String id) {
		return productClassDao.findById(Long.valueOf(id));
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.product.service.ProductDesignService#save(com.rapidtransform.product.model.ProductClass)
	 */
	@Transactional()
	public ProductClass save(ProductClass productClass) {
		Date modified = new Date();
		productClass.setModifiedDate(modified);
		productClass.setModifiedBy(getSecurityService().getAuthenticatedUser());
		return productClassDao.save(productClass);
	}

	/**
	 * Returns the specifications for the given product class.  Since the specifications are 
	 * lazy loaded on the product class, the caller must use this service method to get the specs.
	 */
	public List<Specification> getSpecifications(ProductClass productClass) {
		return productClassDao.getSpecifications(productClass);
	}

	public Product createProduct() {
		Product product = new Product();
		product.setCreatedDate(new Date());
		product.setCreatedBy(getSecurityService().getAuthenticatedUser());
		return product;
	}

	public List<Product> findAllProducts() {
		return productDao.findAll();
	}

	public Product findProduct(String id) {
		return productDao.findById(Long.valueOf(id));
	}

	@Transactional()
	public Product save(Product product) {
		Date modified = new Date();
		product.setModifiedDate(modified);
		product.setModifiedBy(getSecurityService().getAuthenticatedUser());
		return productDao.save(product);
	}

}
