/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 with a permitted attribution clause (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.rapidtransform.com/legal/license.txt
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Convelo Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 */
package com.rapidtransform.product.service.impl;

import java.util.Collection;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.rapidtransform.core.ConveloException;
import com.rapidtransform.core.model.BaseRelation;
import com.rapidtransform.core.model.Model;
import com.rapidtransform.core.model.Relation;
import com.rapidtransform.core.model.namespace.QName;
import com.rapidtransform.core.service.impl.MetaCRUDServiceImpl;
import com.rapidtransform.doc.model.Document;
import com.rapidtransform.doc.model.Documented;
import com.rapidtransform.product.dao.ProductDAO;
import com.rapidtransform.product.model.Product;
import com.rapidtransform.product.model.ProductSpecRelation;
import com.rapidtransform.product.service.ProductService;
import com.rapidtransform.spec.model.SpecRelation;
import com.rapidtransform.spec.model.Specification;
import com.rapidtransform.spec.model.Specified;
import com.rapidtransform.spec.service.SpecService;
import com.rapidtransform.spec.service.SpecifiedService;

/**
 * @author S. Werner
 *
 */
public class ProductServiceImpl extends MetaCRUDServiceImpl<Product> implements ProductService {
	private static Log log = LogFactory.getLog(ProductServiceImpl.class);
	private ProductDAO productDao;
	private SpecService specService;
	
	public ProductDAO getProductDao() {
		return productDao;
	}

	public void setProductDao(ProductDAO productDao) {
		this.productDao = productDao;
		setDao(productDao);
	}

	public ProductServiceImpl() {
		super(Product.class);
	}

	public Log getLog() {
		return log;
	}

	public Collection<Specification> getSpecifications(String relationType, String specifiedId) throws ConveloException {
		Collection<Specification> specs = null;
		specs = productDao.getSpecifications(new QName(relationType), specifiedId);
		return specs;
	}

	/* 
	 * @see com.rapidtransform.spec.service.SpecifiedService#addSpecification(com.rapidtransform.spec.model.Specified, com.rapidtransform.spec.model.Specification, java.lang.String)
	 */
	public Relation<Product, Specification> addSpecification(Specified source, Specification target, String relationType) throws ConveloException {
		Relation<Product, Specification> rel = null;
		if (source instanceof Product) {
			rel = createRelation((Product)source, target, new QName(relationType));
		}
		else {
			log.error("Wrong type passed to createSpecification; expecting Product, received "+source.getClass().getName());
			throw new ConveloException("Wrong type passed to createSpecification; expecting Product, received "+source.getClass().getName());
		}
		return rel;
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.doc.service.DocumentedService#addDocument(com.rapidtransform.doc.model.Documented, com.rapidtransform.doc.model.Document, java.lang.String)
	 */
	public Relation<Product, Document> addDocument(Documented source, Document target, String relationType) throws ConveloException {
		Relation<Product, Document> rel = null;
		if (source instanceof Product) {
			rel = createRelation((Product)source, target, new QName(relationType));
		}
		else {
			log.error("Wrong type passed to addDocument; expecting Product, received "+source.getClass().getName());
			throw new ConveloException("Wrong type passed to addDocument; expecting Product, received "+source.getClass().getName());
		}
		return rel;
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.doc.service.DocumentedService#getDocuments(java.lang.String, java.lang.String)
	 */
	public Collection<Document> getDocuments(String relationQname, String documentedId) throws ConveloException {
		Collection<Document> docs = null;
		docs = productDao.getDocuments(new QName(relationQname), documentedId);
		return docs;
	}

}
