/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.spec.model;

import com.rapidtransform.core.model.AbstractBaseModel;
import com.rapidtransform.org.model.Approvable;
import com.rapidtransform.org.model.OrganizationElement;
import com.rapidtransform.org.model.OrganizationalData;

/**
 * A configuration is the association of a ClassConditionAssociation or ClassSpecAssociation with 
 * a design or process in order to define a valid usage by using the rules specified in the 
 * condition or specification.
 * 
 * @author S. Werner
 *
 */
public class Configuration extends AbstractBaseModel 
	implements Approvable, OrganizationElement, OrganizationalData, Effective {
	
	/**
	 * Specifies the valid usage of a configuration on a 
	 * @author S. Werner
	 *
	 */
	public enum ConfigurationType {
		/**
		 * The configed element object must be designed or verified before used in the given context specified
		 * by the solutionFor attribute. 
		 */
		DESIGN,
		
		/**
		 * The condition or spec specifies a use case for the solutionFor object and the configured element
		 * has the given Configuration.
		 */
		USAGE;
	}
	private ConfigurationType configType;
	
	/**
	 * The InheritanceType specifies how this Configuration should be applied in a hierarchical structure.
	 */
	public enum InheritanceType {
		/**
		 * This value indicates the the Configuration at the specified level is contradictory or an
		 * exception to the rules in the hierarchy above the configured element.  This also signifies that
		 * the Configuration only applies to the local object.
		 */
		EXCEPTION,
		/**
		 * This value indicates that this Configuration is inherited by combining all the configurations
		 * on the configured element.  Effectivity is considered when creating this Configuration.
		 */
		INHERITED,
		/**
		 * No inheritance is valid and all configuration information must be attached locally.
		 */
		LOCAL;
	}
	private InheritanceType inheritanceType;
	
	private ConfiguredSpec solutionFor;

	public ConfigurationType getConfigType() {
		return configType;
	}

	public void setConfigType(ConfigurationType configType) {
		this.configType = configType;
	}

	public InheritanceType getInheritanceType() {
		return inheritanceType;
	}

	public void setInheritanceType(InheritanceType inheritanceType) {
		this.inheritanceType = inheritanceType;
	}

	public ConfiguredSpec getSolutionFor() {
		return solutionFor;
	}

	public void setSolutionFor(ConfiguredSpec solutionFor) {
		this.solutionFor = solutionFor;
	}
	
}
