/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.spec.model;

import com.rapidtransform.core.model.AbstractBaseModel;

/**
 * Assigns an effectivity to an object that implements the Effective interface.
 * 
 * @author S. Werner
 *
 */
public class EffectivityAssignment extends AbstractBaseModel {
	public enum EffectivityRole {
		/**
		 * The actual period the effectivity applied
		 */
		ACTUAL,
		/**
		 * the planned period the effectivity is, will, or was supposed to be applied.
		 */
		PLANNED,
		/**
		 * The associated is required to be effective during this period. 
		 */
		REQUIRED;
	}
	private EffectivityRole role;
	
	/**
	 * Specifies whether the linked object is effective or ineffective for the given period of time.
	 * A value of True indicates effective and a value of False indicates ineffective.
	 */
	private Boolean effective;
	
	/**
	 * Indicates the object for which the effectivity applies.
	 */
	private Effective appliedTo;

	/**
	 * @return Returns the appliedTo.
	 */
	public Effective getAppliedTo() {
		return appliedTo;
	}

	/**
	 * @param appliedTo The appliedTo to set.
	 */
	public void setAppliedTo(Effective appliedTo) {
		this.appliedTo = appliedTo;
	}

	/**
	 * @return Returns the effective.
	 */
	public Boolean getEffective() {
		return effective;
	}

	/**
	 * @param effective The effective to set.
	 */
	public void setEffective(Boolean effective) {
		this.effective = effective;
	}

	/**
	 * @return Returns the role.
	 */
	public EffectivityRole getRole() {
		return role;
	}

	/**
	 * @param role The role to set.
	 */
	public void setRole(EffectivityRole role) {
		this.role = role;
	}

	
}
