/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.spec.model;

import java.util.Set;

import com.rapidtransform.core.model.AbstractBaseModel;
import com.rapidtransform.org.model.Approvable;
import com.rapidtransform.org.model.Organization;
import com.rapidtransform.org.model.OrganizationElement;
import com.rapidtransform.org.model.OrganizationalData;
import com.rapidtransform.product.model.ProductDesign;

/**
 * The manufacturing configuration is the association of a product design with an
 * item instance.
 * 
 * @author S. Werner
 *
 */
public abstract class ManufacturingConfig extends AbstractBaseModel 
	implements Approvable, OrganizationElement, OrganizationalData {
	
	/**
	 * This is the set of organizations that are concerned with this Manufacturing configuration.
	 */
	private Set<Organization> organizations;
	
	/**
	 * This attribute specifies the ProductDesign for which this configuration is a solution.
	 */
	private ProductDesign solutionFor;

	/**
	 * @return Returns the organizations.
	 */
	public Set<Organization> getOrganizations() {
		return organizations;
	}

	/**
	 * @param organizations The organizations to set.
	 */
	public void setOrganizations(Set<Organization> organizations) {
		this.organizations = organizations;
	}

	/**
	 * @return Returns the solutionFor.
	 */
	public ProductDesign getSolutionFor() {
		return solutionFor;
	}

	/**
	 * @param solutionFor The solutionFor to set.
	 */
	public void setSolutionFor(ProductDesign solutionFor) {
		this.solutionFor = solutionFor;
	}
	
	
}
