/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.spec.model;

import java.util.Set;

import com.rapidtransform.classification.model.Classified;
import com.rapidtransform.core.model.AbstractBaseModel;
import com.rapidtransform.doc.model.Document;
import com.rapidtransform.org.model.Alias;
import com.rapidtransform.org.model.Approvable;
import com.rapidtransform.org.model.OrganizationElement;
import com.rapidtransform.org.model.OrganizationalData;

/**
 * The spec category is a group of specifications which serve the same purpose.
 * 
 * @author S. Werner
 *
 */
public class SpecCategory extends AbstractBaseModel 
	implements Classified, Approvable, OrganizationElement, OrganizationalData, Effective {
	
	/**
	 * If true, then the specifications in this category are mutually exclusive.
	 */
	private Boolean exclusive;
	
	private String categoryId;
	private SpecCategory parent;
	private Set<SpecCategory> subCategories;
	private String description;
	private Set<Document> documents;
	private Set<Alias> aliases;
	/**
	 * @return Returns the aliases.
	 */
	public Set<Alias> getAliases() {
		return aliases;
	}
	/**
	 * @param aliases The aliases to set.
	 */
	public void setAliases(Set<Alias> aliases) {
		this.aliases = aliases;
	}
	/**
	 * @return Returns the categoryId.
	 */
	public String getCategoryId() {
		return categoryId;
	}
	/**
	 * @param categoryId The categoryId to set.
	 */
	public void setCategoryId(String categoryId) {
		this.categoryId = categoryId;
	}
	/**
	 * @return Returns the description.
	 */
	public String getDescription() {
		return description;
	}
	/**
	 * @param description The description to set.
	 */
	public void setDescription(String description) {
		this.description = description;
	}
	/**
	 * @return Returns the documents.
	 */
	public Set<Document> getDocuments() {
		return documents;
	}
	/**
	 * @param documents The documents to set.
	 */
	public void setDocuments(Set<Document> documents) {
		this.documents = documents;
	}
	/**
	 * @return Returns the exclusive.
	 */
	public Boolean getExclusive() {
		return exclusive;
	}
	/**
	 * @param exclusive The exclusive to set.
	 */
	public void setExclusive(Boolean exclusive) {
		this.exclusive = exclusive;
	}
	public SpecCategory getParent() {
		return parent;
	}
	public void setParent(SpecCategory parent) {
		this.parent = parent;
	}
	public Set<SpecCategory> getSubCategories() {
		return subCategories;
	}
	public void setSubCategories(Set<SpecCategory> subCategories) {
		this.subCategories = subCategories;
	}
	
}
