/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.spec.model;

import java.util.Set;

import com.rapidtransform.core.model.AbstractBaseModel;
import com.rapidtransform.org.model.Approvable;
import com.rapidtransform.org.model.OrganizationElement;
import com.rapidtransform.org.model.OrganizationalData;

/**
 * Combination of specification objects combined with a boolean operators.
 * 
 * TODO can specification objects be expressed with a rules engine like Drools?
 * 
 * @author S. Werner
 *
 */
public class SpecExpression extends AbstractBaseModel 
	implements Approvable, OrganizationElement, OrganizationalData, Effective, SpecOperand {
	
	public enum Operator {
		AND, OR, ONEOF, NOT;
	}
	private Operator operator;
	private String expressionId;
	private Set<SpecInclusion> inclusion;
	private String description;
	
	/**
	 * The operands specify the operands which are combined by the operator to complete the expression.
	 */
	private Set<SpecOperand> operands;
	
	/**
	 * @return Returns the expressionId.
	 */
	public String getExpressionId() {
		return expressionId;
	}
	/**
	 * @param expressionId The expressionId to set.
	 */
	public void setExpressionId(String expressionId) {
		this.expressionId = expressionId;
	}
	/**
	 * @return Returns the operator.
	 */
	public Operator getOperator() {
		return operator;
	}
	/**
	 * @param operator The operator to set.
	 */
	public void setOperator(Operator operator) {
		this.operator = operator;
	}
	/**
	 * @return Returns the description.
	 */
	public String getDescription() {
		return description;
	}
	/**
	 * @param description The description to set.
	 */
	public void setDescription(String description) {
		this.description = description;
	}
	/**
	 * @return Returns the inclusion.
	 */
	public Set<SpecInclusion> getInclusion() {
		return inclusion;
	}
	/**
	 * @param inclusion The inclusion to set.
	 */
	public void setInclusion(Set<SpecInclusion> inclusion) {
		this.inclusion = inclusion;
	}
	/**
	 * @return Returns the operands.
	 */
	public Set<SpecOperand> getOperands() {
		return operands;
	}
	/**
	 * @param operands The operands to set.
	 */
	public void setOperands(Set<SpecOperand> operands) {
		this.operands = operands;
	}
	
	
}
