/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.spec.model;

import java.util.Set;

import com.rapidtransform.core.model.AbstractBaseModel;
import com.rapidtransform.core.model.VersionControlled;
import com.rapidtransform.core.util.EqualsUtil;
import com.rapidtransform.doc.model.Document;
import com.rapidtransform.org.model.Alias;
import com.rapidtransform.org.model.Approvable;
import com.rapidtransform.org.model.OrganizationElement;
import com.rapidtransform.org.model.OrganizationalData;

/**
 * A specification is a defined rule for a product and it discriminates one product from another
 * member in the same product class.  The SpecCategory defines the semantics for the Specification.
 * 
 * @author S. Werner
 *
 */
public class Specification extends VersionControlled 
	implements Approvable, OrganizationElement, OrganizationalData, Effective, SpecOperand {
	
	/**
	 * TODO must be unique
	 */
	private String specId;
	private String versionId;
	
	/**
	 * If this attribute is true, then this specification object is a package of specifications where there
	 * is one specInclusion for each ProductClass that uses this spec as a 'ifCondition'.  Otherwise,
	 * there is only one specInclusion.
	 * 
	 */
	private Boolean specPackage;
	
	private SpecInclusion specInclusion;
	private String description;
	private String name;
	private Set<Alias> aliases;
	private SpecCategory specCategory;
	/**
	 * @return Returns the aliases.
	 */
	public Set<Alias> getAliases() {
		return aliases;
	}
	/**
	 * @param aliases The aliases to set.
	 */
	public void setAliases(Set<Alias> aliases) {
		this.aliases = aliases;
	}
	/**
	 * @return Returns the description.
	 */
	public String getDescription() {
		return description;
	}
	/**
	 * @param description The description to set.
	 */
	public void setDescription(String description) {
		this.description = description;
	}
	/**
	 * @return Returns the name.
	 */
	public String getName() {
		return name;
	}
	/**
	 * @param name The name to set.
	 */
	public void setName(String name) {
		this.name = name;
	}
	/**
	 * @return Returns the specCategory.
	 */
	public SpecCategory getSpecCategory() {
		return specCategory;
	}
	/**
	 * @param specCategory The specCategory to set.
	 */
	public void setSpecCategory(SpecCategory specCategory) {
		this.specCategory = specCategory;
	}
	/**
	 * @return Returns the specId.
	 */
	public String getSpecId() {
		return specId;
	}
	/**
	 * @param specId The specId to set.
	 */
	public void setSpecId(String specId) {
		this.specId = specId;
	}
	/**
	 * @return Returns the specInclusion.
	 */
	public SpecInclusion getSpecInclusion() {
		return specInclusion;
	}
	/**
	 * @param specInclusion The specInclusion to set.
	 */
	public void setSpecInclusion(SpecInclusion specInclusion) {
		this.specInclusion = specInclusion;
	}
	/**
	 * @return Returns the specPackage.
	 */
	public Boolean getSpecPackage() {
		return specPackage;
	}
	/**
	 * @param specPackage The specPackage to set.
	 */
	public void setSpecPackage(Boolean specPackage) {
		this.specPackage = specPackage;
	}
	/**
	 * @return Returns the versionId.
	 */
	public String getVersionId() {
		return versionId;
	}
	/**
	 * @param versionId The versionId to set.
	 */
	public void setVersionId(String versionId) {
		this.versionId = versionId;
	}
	
}
