/**
 * The contents of this file are subject to the Rapid Transform Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.rapidtransform.com/license.html
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.spec.service.impl;

import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.transaction.annotation.Transactional;

import com.rapidtransform.core.service.impl.MetaCRUDServiceImpl;
import com.rapidtransform.core.service.impl.ServiceImpl;
import com.rapidtransform.spec.dao.SpecCategoryDAO;
import com.rapidtransform.spec.dao.SpecDAO;
import com.rapidtransform.spec.model.AbstractSpecRelation;
import com.rapidtransform.spec.model.SpecCategory;
import com.rapidtransform.spec.model.SpecRelation;
import com.rapidtransform.spec.model.Specification;
import com.rapidtransform.spec.service.SpecService;

/**
 * @author S. Werner
 *
 */
public class SpecServiceImpl extends MetaCRUDServiceImpl<Specification> implements SpecService {
	
	private static Log log = LogFactory.getLog(SpecServiceImpl.class);
	
	private SpecDAO specDao;
	private SpecCategoryDAO specCategoryDao;
	
	public SpecServiceImpl() {
		super(Specification.class);
	}
	
	public Log getLog() {
		return log;
	}
	
	public void setSpecDao(SpecDAO dao) {
		this.specDao = dao;
		setDao(specDao);
	}
	public void setSpecCategoryDao(SpecCategoryDAO dao) {
		this.specCategoryDao = dao;
	}

	public List<Specification> findAllSpecifications() {
		return specDao.findAll();
	}

	public Specification findSpecification(String id) {
		return specDao.findById(Long.valueOf(id));
	}

	@Transactional()
	public SpecCategory save(SpecCategory category) {
		return specCategoryDao.save(category);
	}

	public SpecCategory findSpecCategory(String id) {
		return specCategoryDao.findById(Long.valueOf(id));
	}

	public List<SpecCategory> findTopLevelCategories() {
		return specCategoryDao.findTopLevelCategories();
	}

}
