/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 with a permitted attribution clause (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.rapidtransform.com/legal/license.txt
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Convelo Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005,2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 */
package com.rapidtransform.admin.client;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.opensymphony.xwork.ActionContext;
import com.opensymphony.xwork.ActionSupport;
import com.rapidtransform.admin.model.Role;
import com.rapidtransform.admin.model.User;
import com.rapidtransform.admin.model.UserRoleRelation;
import com.rapidtransform.admin.service.UserService;

/**
 * @author S. Werner
 *
 */
public class UserAction extends ActionSupport {
    private static Log log = LogFactory.getLog(UserAction.class);
    private UserService userService = null;
    private String userId;
    private User user;
    private Set<UserRoleRelation> userRoles;
    private List<User> userList;
    private String passwordVerify;
    private List<String> selectedRoles;

    public void setUserService(UserService userService) {
        this.userService = userService;
    }
    
    public String getUserId() {
		return userId;
	}

	public void setUserId(String userId) {
		this.userId = userId;
	}
	
	public User getUser() {
		return user;
	}

	public void setUser(User user) {
		this.user = user;
	}
	
	public List<User> getUserList() {
		return userList;
	}

	public void setUserList(List<User> userList) {
		this.userList = userList;
	}
	
	public String getPasswordVerify() {
		return passwordVerify;
	}

	public void setPasswordVerify(String passwordVerify) {
		this.passwordVerify = passwordVerify;
	}
	
	public List<String> getSelectedRoles() {
		return selectedRoles;
	}

	public void setSelectedRoles(List<String> selectedRoles) {
		this.selectedRoles = selectedRoles;
	}
	
	public Set<UserRoleRelation> getUserRoles() {
		return userRoles;
	}

	public void setUserRoles(Set<UserRoleRelation> userRoles) {
		this.userRoles = userRoles;
	}

	public String execute() throws Exception {
    	return SUCCESS;
    }

    public String remove() throws Exception {
    	return SUCCESS;
    }
    
    public String edit() throws Exception {
    	ActionContext context = ActionContext.getContext();
		if (userId == null) {
			// if not already set, try to get it from the request parameters
			Map requestParams = context.getParameters();
			userId = (String)requestParams.get("userId");
		}
        if (log.isDebugEnabled()) log.debug("Editing user: "+getUserId());

        // null userId indicates an create
        if (userId != null) {
            user = userService.getUser(userId);
            if (user == null) {
            	// TODO error handling ActionMessage("user.missing")
            	log.error("User not found "+userId);
                return ERROR;
            }
            selectedRoles = new ArrayList<String>();
            // set the selected roles for the user being updated
            for (UserRoleRelation link : user.getRoles()) {
            	log.debug("Adding role "+link.getRole().getId() + " for user "+ user.getUsername());
            	selectedRoles.add(Long.toString(link.getRole().getId()));
            }
        }
    	return SUCCESS;
    }
    
    public String view() throws Exception {
    	ActionContext context = ActionContext.getContext();
		if (userId == null) {
			// if not already set, try to get it from the request parameters
			Map requestParams = context.getParameters();
			userId = (String)requestParams.get("userId");
		}
      	if (log.isDebugEnabled()) log.debug("In view(), getting user: "+userId);
        user = userService.getUser(userId);
        userRoles = userService.getUserRoles(userId);
        log.debug("user roles: "+userRoles.size());
    	if (user == null) {
    		//ActionMessages errors = new ActionMessages();
            //errors.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("user.missing"));
            //saveErrors(request, errors);
    		log.error("User not found "+userId);
    		// TODO error handling
    	}
        //roles = user.getRoles();
        return SUCCESS;
    }
    
    public String list() throws Exception {
    	log.debug("listing users...");
        userList = userService.getUsers();
        if (log.isDebugEnabled()) log.debug("User list size: "+userList.size());
    	return SUCCESS;
    }
    
    public String save() throws Exception {
        if (passwordVerify.compareTo(user.getPassword()) != 0) {
        	//ActionErrors errors = new ActionErrors();
        	//errors.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("user.checkpassword"));
        	//saveMessages(request, errors);
        	// TODO error handling for password match
        	return ERROR;
        }
        if (selectedRoles != null) {
        	log.debug("Number of roles for user: "+selectedRoles.size());
        	HashSet<UserRoleRelation> userRoleSet = new HashSet<UserRoleRelation>();
        	for (String roleId : selectedRoles) {
        		log.debug("getting role: "+roleId);
        		UserRoleRelation userRole = new UserRoleRelation();
        		userRole.setRole(userService.getRole(roleId));
        		userRoleSet.add(userRole);
        	}
        	user.setRoles(userRoleSet);
        }
        else
        	log.debug("selected roles is null");
        userService.saveUser(user);
    	return SUCCESS;
    }
    
}
