/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 with a permitted attribution clause (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.rapidtransform.com/legal/license.txt
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Convelo Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005,2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 */
package com.rapidtransform.core.client;

import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.springframework.dao.DataAccessException;

import com.opensymphony.xwork.ActionContext;
import com.opensymphony.xwork.ActionSupport;
import com.rapidtransform.core.service.CRUDService;

/**
 * This action class defines common methods for basic create, update, read and delete.  All special behavior
 * should be overridden in the child class of this generic CRUD action.
 * 
 * @author S. Werner
 *
 */
public abstract class CRUDAction<Type> extends ActionSupport {
	private Type entity;
	private Long entityId;
	private List<Type> entities;
	
	public List<Type> getEntities() {
		return entities;
	}

	public void setEntities(List<Type> entities) {
		this.entities = entities;
	}

	public Type getEntity() {
		return entity;
	}

	public void setEntity(Type entity) {
		this.entity = entity;
	}

	public Long getEntityId() {
		return entityId;
	}

	public void setEntityId(Long entityId) {
		this.entityId = entityId;
	}

	public String list() throws Exception {
		List<Type> all = getService().findAll();
		setEntities(all);
		return SUCCESS;
	}
	
	public String edit() throws Exception {
		getLog().debug("Executing edit()...");
		ActionContext context = ActionContext.getContext();
    	Map requestParams = context.getParameters();
		if (entityId == null) {
			// if not already set, try to get it from the request parameters
			Object id = requestParams.get("entityId");
			if (id instanceof String) {
				entityId = Long.valueOf((String)id);
			}
		}
		if (entityId == null) { // create a new entity
			getLog().debug("creating a new entity");
			entity = (Type)getService().create();
		}
		else {
			// retrieve an existing entity
			entity = (Type)getService().find(entityId);
		}
		return SUCCESS;
	}
	
	public String save() throws Exception {
		getLog().debug("Saving entity "+entity);
		try {
			if (this.entity != null) {
				entity = (Type)getService().save(entity);
			}
			//else log.debug("save() specification is null");
		} catch (DataAccessException dae) {
			getLog().error("Error saving entity "+entity, dae);
			return ERROR;
		}
		return SUCCESS;
	}
	
	public String view() throws Exception {
	   	ActionContext context = ActionContext.getContext();
		if (entityId == null) {
			// if not already set, try to get it from the request parameters
			Map requestParams = context.getParameters();
			Object id = requestParams.get("entityId");
			if (id instanceof String) {
				entityId = Long.valueOf((String)id);
			}
		}
		getLog().debug("Retrieving object with id "+entityId+" for view.");
		entity = getService().find(entityId);
		if (entity == null) {
			// TODO error handling
			return ERROR;
		}
		return SUCCESS;
	}
	
	public abstract CRUDService<Type> getService();
	
	public abstract Log getLog();
}
