/**
 * 
 */
package com.rapidtransform.core.client;

import java.util.List;

import com.rapidtransform.core.model.Model;
import com.rapidtransform.core.model.namespace.QName;
import com.rapidtransform.core.service.CRUDService;
import com.rapidtransform.core.service.MetaCRUDService;
import com.rapidtransform.core.type.DynamicPropertyHolder;
import com.rapidtransform.core.type.PropertyHolder;


/**
 * @author Steve Werner
 *
 */
public abstract class MetaCRUDAction<Type extends Model> extends CRUDAction<Type> implements MetaAction {

	private String type;
	
	/**
	 * @return Returns the metaType.
	 */
	public String getType() {
		if (type == null && getEntity() != null) {
			type = ((Type)getEntity()).getMetaTypeName().toString();
		}
		return type;
	}

	/**
	 * @param type The metaType to set.
	 */
	public void setType(String metaType) {
		this.type = metaType;
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.core.client.MetaAction#getPropertyHolder()
	 */
	public PropertyHolder getPropertyHolder() {
		if (getEntity() != null) {
			return ((Type)getEntity()).getPropertyHolder();
		}
		else {
			return new DynamicPropertyHolder();
		}
	}
	

	/* (non-Javadoc)
	 * @see com.rapidtransform.core.client.CRUDAction#edit()
	 */
	@Override
	public String edit() throws Exception {
		String retValue = super.edit();
		if (getType() != null && getEntity() != null) {
			QName typeQName = new QName(getType());
			getEntity().setMetaTypeName(typeQName);
			if (((Type)getEntity()).getPropertyHolder() == null) {
				((Type)getEntity()).setPropertyHolder(new DynamicPropertyHolder());
			}
			((Type)getEntity()).getPropertyHolder().setMetaTypeName(typeQName);
		}
		return retValue;
	}
	
	public abstract MetaCRUDService<Type> getService();
	
	public String list() throws Exception {
		if (type != null) {
			setEntities(getService().findByMetaType(type));
		}
		else {
			setEntities(getService().findAll());
		}
		return SUCCESS;
	}

}
