/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 with a permitted attribution clause (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.rapidtransform.com/legal/license.txt
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Convelo Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005,2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 */
package com.rapidtransform.core.client;

import java.util.List;
import java.util.Map;

import com.opensymphony.xwork.ActionContext;
import com.opensymphony.xwork.ActionSupport;
import com.opensymphony.webwork.interceptor.SessionAware;
import com.rapidtransform.core.model.Module;
import com.rapidtransform.core.service.ModuleService;

/**
 * @author S. Werner
 *
 */
public class ModuleAction extends ActionSupport implements SessionAware {
	private ModuleService moduleService;
	private String moduleName;
	private Map session;
	
	public static final String ACTIVE_MODULE = "convelo_activeModule";
	
	private static final String DEFAULT_MODULE = "home";
	
	public void setSession(Map session) {
		this.session = session;
	}

	public void setModuleService(ModuleService service) {
		this.moduleService = service;
	}
	
	public void setModuleName(String name) {
		this.moduleName = name;
	}
	
	public String getModuleName() {
		return moduleName;
	}
	
	public Module getModule() {
		return (Module)session.get(ACTIVE_MODULE);
	}

	public void setModule(Module module) {
		if (module != null) {
			session.put(ACTIVE_MODULE, module);
		}
		else {
			session.remove(ACTIVE_MODULE);
		}
	}
	
	public List<Module> getActiveModules() {
		System.out.println("getting active modules");
		List<Module> modules = moduleService.getActiveModules();
		System.out.println("number of active modules: "+modules.size());
		return moduleService.getActiveModules();
	}

	@Override
	public String execute() throws Exception {
		System.out.println("executing");
		return super.execute();
	}
	
	/**
	 * Switches the view to a new module.  If the module specified by the "moduleName" 
	 * is not found, then the view is forwarded to the default module (home).
	 * 
	 * @return
	 * @throws Exception
	 */
	public String switchModule() throws Exception {
		
		ActionContext context = ActionContext.getContext();
		if (getModuleName() == null) {
			// if not already set, try to get it from the request parameters
			Map requestParams = context.getParameters();
			String modName = (String)requestParams.get("moduleName");
			setModuleName(modName);
		}
		if (getModuleName() == null || getModuleName().length() == 0) {
			// if the module name is null or empty, then set it to the default = home
			setModuleName(DEFAULT_MODULE);
		}
		Module mod = moduleService.getModule(getModuleName());
		if (mod == null) {
			addActionError(getText("com.rapidtransform.core.client.ModuleAction.notfound", getModuleName()));
			Module homeModule = moduleService.getModule(DEFAULT_MODULE);
			setModule(homeModule);
			return ERROR;
		}
		setModule(mod);
	
		return SUCCESS;
	}


}
