/**
 * 
 */
package com.rapidtransform.core.client.util;

import java.io.Serializable;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.opensymphony.xwork.ActionInvocation;
import com.opensymphony.xwork.interceptor.Interceptor;
import com.opensymphony.xwork.util.XWorkConverter;
import com.rapidtransform.core.client.MetaAction;
import com.rapidtransform.core.meta.MetaProperty;
import com.rapidtransform.core.meta.MetaService;
import com.rapidtransform.core.meta.MetaType;

/**
 * @author Steve Werner
 *
 */
public class MetaConversionInterceptor implements Interceptor {
	
	private static Log log = LogFactory.getLog(MetaConversionInterceptor.class);
	private MetaService metaService;
	
	/**
	 * @return Returns the metaService.
	 */
	public MetaService getMetaService() {
		return metaService;
	}

	/**
	 * @param metaService The metaService to set.
	 */
	public void setMetaService(MetaService metaService) {
		this.metaService = metaService;
	}
	
	/* (non-Javadoc)
	 * @see com.opensymphony.xwork.interceptor.Interceptor#destroy()
	 */
	public void destroy() {
	}

	/* (non-Javadoc)
	 * @see com.opensymphony.xwork.interceptor.Interceptor#init()
	 */
	public void init() {
	}

	/* (non-Javadoc)
	 * @see com.opensymphony.xwork.interceptor.Interceptor#intercept(com.opensymphony.xwork.ActionInvocation)
	 */
	public String intercept(ActionInvocation actionInvocation) throws Exception {
		log.debug("MetaConversionInterceptor converting meta properties types...");
		Object action = actionInvocation.getAction();
		if (action instanceof MetaAction) {
			MetaAction metaAction = (MetaAction)action;
			if (metaAction.getPropertyHolder() != null) {
				Map<String, Object> properties = metaAction.getPropertyHolder().getProperties();
				for (String key : properties.keySet()) {
	            	MetaProperty metaProp = metaService.getProperty(key);
	            	if (metaProp != null) {
	            		MetaType metaType = metaService.getType(metaProp.getType());
	            		Object converted = XWorkConverter.getInstance().convertValue(actionInvocation.getInvocationContext().getContextMap(), properties.get(key), Class.forName(metaType.getJavaClass()));
	            		properties.put(key, (Serializable)converted);
	            	}
				}
			}
		}
		return actionInvocation.invoke();
	}

}
