/**
 * The contents of this file are subject to the Rapid Transform Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.rapidtransform.com/license.html
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.core.service;

import java.util.List;

import com.rapidtransform.core.model.Module;

/**
 * The ModuleService manages the modules for the application.  The service will store the deployed or
 * undeployed state of each module so the client can determine if the module is active.
 * 
 * @author S. Werner
 *
 */
public interface ModuleService extends Service {
	/**
	 * returns a list of all available modules in the application, including active and inactive modules.
	 * @return
	 */
	public List<Module> getModules();
	
	/**
	 * returns a list of only the active modules for the application.
	 * @return
	 */
	public List<Module> getActiveModules();
	
	/**
	 * Returns the module associated with the given name.
	 * @param name
	 * @return
	 */
	public Module getModule(String name);

}
