/**
 * The contents of this file are subject to the Rapid Transform Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at 
 * http://www.rapidtransform.com/license.html
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Rapid PLM Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005 Rapid Transform, Inc. 
 * All Rights Reserved.
 * 
 * Contributor(s): ______________________________________.
 */
package com.rapidtransform.core.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.rapidtransform.core.model.Module;
import com.rapidtransform.core.service.ModuleService;

/**
 * Default implementation for the ModuleService manager.
 * 
 * @author S. Werner
 *
 */
public class ModuleServiceImpl implements ModuleService {
	
	private Log log = LogFactory.getLog(ModuleServiceImpl.class); 

	private List<Module> modules;
	
	public void setModules(List<Module> modules) {
		this.modules = modules;
	}
	
	public List<Module> getModules() {
		return modules;
	}

	public List<Module> getActiveModules() {
		ArrayList<Module> activeModules = new ArrayList<Module>();
		for (Module module : modules) {
			if (module.getActive()) {
				activeModules.add(module);
			}
		}
		return activeModules;
	}
	
	public Module getModule(String name) {
		if (log.isDebugEnabled()) log.debug("Executing getModule("+name+")");
		for (Module module : modules) {
			if (module.getName().equals(name)) {
				if (log.isDebugEnabled()) log.debug("Module found for name "+name);
				return module;
			}
		}
		log.error("Module not found with name "+name);
		return null;
	}

}
