/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 with a permitted attribution clause (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.rapidtransform.com/legal/license.txt
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Convelo Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005,2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 */
package com.rapidtransform.doc.client;

import java.io.File;
import java.io.FileInputStream;
import java.util.Collection;
import java.util.Map;

import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.dao.DataAccessException;

import com.opensymphony.webwork.interceptor.ServletResponseAware;
import com.opensymphony.xwork.ActionContext;
import com.rapidtransform.core.client.MetaCRUDAction;
import com.rapidtransform.core.service.MetaCRUDService;
import com.rapidtransform.doc.service.DocumentService;
import com.rapidtransform.doc.model.Document;

/**
 * @author S. Werner
 *
 */
public class DocumentAction extends MetaCRUDAction<Document> implements ServletResponseAware {
	
	private static Log log = LogFactory.getLog(DocumentAction.class);
	
	private DocumentService documentService;
	private Collection<Document> docs;

	private HttpServletResponse servletResponse;
	private File upload;
	private String uploadContentType;
	private String uploadFileName;
	
	public Document getDocument() {
		return getEntity();
	}
	public void setDocument(Document doc) {
		setEntity(doc);
	}
	/**
	 * @return Returns the docs.
	 */
	public Collection<Document> getDocs() {
		return docs;
	}
	/**
	 * @param docs The docs to set.
	 */
	public void setDocs(Collection<Document> docs) {
		this.docs = docs;
	}
	/**
	 * @param documentService The documentService to set.
	 */
	public void setDocumentService(DocumentService documentService) {
		this.documentService = documentService;
	}
	public File getUpload() {
		return upload;
	}
	public void setUpload(File upload) {
		this.upload = upload;
	}
	public String getUploadContentType() {
		return uploadContentType;
	}
	public void setUploadContentType(String uploadContentType) {
		this.uploadContentType = uploadContentType;
	}
	public String getUploadFileName() {
		return uploadFileName;
	}
	public void setUploadFileName(String uploadFileName) {
		this.uploadFileName = uploadFileName;
	}
	
	public String save() throws Exception {
		log.debug("Saving document "+getEntity());
		try {
			if (getDocument() != null) {
				FileInputStream fis = new FileInputStream(getUpload());
				byte[] fileBytes = new byte[Long.valueOf(getUpload().length()).intValue()];
				while (fis.read(fileBytes) != -1);
				getDocument().setContent(fileBytes);
				getDocument().setContentType(uploadContentType);
				getDocument().setFileName(uploadFileName);
				getDocument().setFileSize(Long.valueOf(getUpload().length()).intValue());
				setDocument(documentService.save(getDocument()));
			}
		} catch (DataAccessException dae) {
			log.error("Error saving document "+getDocument(), dae);
			return ERROR;
		}
		return SUCCESS;
	}

	public String viewContent() throws Exception {
		ActionContext context = ActionContext.getContext();
		if (getEntityId() == null) {
			// if not already set, try to get it from the request parameters
			Map requestParams = context.getParameters();
			Object id = requestParams.get("entityId");
			if (id instanceof String) {
				setEntityId(Long.valueOf((String)id));
			}
		}
		getLog().debug("Retrieving object with id "+getEntityId()+" for content view.");
		setEntity(documentService.find(getEntityId()));
		
		getServletResponse().setContentType(getDocument().getContentType());
		getServletResponse().setHeader("Content-disposition", "filename="+getDocument().getFileName());
		getServletResponse().getOutputStream().write(getDocument().getContent());
		getServletResponse().getOutputStream().flush();
		getServletResponse().getOutputStream().close();
		
		return NONE;
	}

	public HttpServletResponse getServletResponse() {
		return servletResponse;
	}
	public void setServletResponse(HttpServletResponse arg0) {
		servletResponse = arg0;
	}
	
	public String execute() throws Exception {
		return SUCCESS;
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.core.client.CRUDAction#getLog()
	 */
	@Override
	public Log getLog() {
		return log;
	}
	
	public MetaCRUDService<Document> getService() {
		return documentService;
	}
	
}
