/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 with a permitted attribution clause (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.rapidtransform.com/legal/license.txt
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Convelo Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005,2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 */
package com.rapidtransform.doc.client;

import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.opensymphony.xwork.ActionContext;
import com.rapidtransform.doc.service.DocumentService;
import com.rapidtransform.part.model.ItemVersion;
import com.rapidtransform.part.service.ItemService;
import com.rapidtransform.product.model.Product;
import com.rapidtransform.product.service.ProductService;

/**
 * @author S. Werner
 *
 */
public class ItemDocumentAction extends DocumentAction {
	private static Log log = LogFactory.getLog(ItemDocumentAction.class);
	
	private ItemVersion itemVersion;
	private ItemService itemService;
	private String relationType;
	private String sourceId;
	
	/**
	 * @return Returns the itemService.
	 */
	public ItemService getItemService() {
		return itemService;
	}

	/**
	 * @param itemService The itemService to set.
	 */
	public void setItemService(ItemService itemService) {
		this.itemService = itemService;
	}

	/**
	 * @return Returns the itemVersion.
	 */
	public ItemVersion getItemVersion() {
		return itemVersion;
	}

	/**
	 * @param itemVersion The itemVersion to set.
	 */
	public void setItemVersion(ItemVersion itemVersion) {
		this.itemVersion = itemVersion;
	}

	/**
	 * @return Returns the relationType.
	 */
	public String getRelationType() {
		return relationType;
	}

	/**
	 * @param relationType The relationType to set.
	 */
	public void setRelationType(String relationType) {
		this.relationType = relationType;
	}
	
	/**
	 * @return Returns the sourceId.
	 */
	public String getSourceId() {
		return sourceId;
	}

	/**
	 * @param sourceId The sourceId to set.
	 */
	public void setSourceId(String sourceId) {
		this.sourceId = sourceId;
	}

	/* (non-Javadoc)
	 * @see com.rapidtransform.core.client.CRUDAction#save()
	 */
	@Override
	public String save() throws Exception {
		boolean update = false;
		if (getEntity().getId() != null) 
			update = true;
		
		super.save();
		if (getSourceId() != null) {
			itemVersion = itemService.find(Long.valueOf(getSourceId()));
		}
		
		if (!update)
			itemService.addDocument(itemVersion, getDocument(), relationType);
		
		return SUCCESS;
	}	
	
	/* 
	 * Gets a list of specification for the product
	 */
	@Override
	public String list() throws Exception {
		ActionContext context = ActionContext.getContext();
		if (getSourceId() == null) {
			Map requestParams = context.getParameters();
			Object id = requestParams.get("sourceId");
			if (id instanceof String) {
				setSourceId((String)id);
			}
		}
		setDocs(itemService.getDocuments(getRelationType(), sourceId));
		return SUCCESS;
	}	
}
