/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 with a permitted attribution clause (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.rapidtransform.com/legal/license.txt
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Convelo Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005,2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 */
package com.rapidtransform.product.client;

import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.dao.DataAccessException;

import com.opensymphony.xwork.ActionContext;
import com.opensymphony.xwork.ActionSupport;
import com.rapidtransform.product.model.ProductClass;
import com.rapidtransform.product.service.ProductDesignService;
import com.rapidtransform.spec.model.Specification;

/**
 * @author S. Werner
 *
 */
public class ProductClassAction extends ActionSupport {
	private static Log log = LogFactory.getLog(ProductClassAction.class);
	
	private ProductDesignService productDesignService;
	private List<ProductClass> productClasses;
	private String classId;
	private ProductClass productClass;
	private List<Specification> specs; 
	private String specParentId;

	public String getClassId() {
		return classId;
	}
	public void setClassId(String classId) {
		this.classId = classId;
	}
	public ProductClass getProductClass() {
		return productClass;
	}
	public void setProductClass(ProductClass productClass) {
		this.productClass = productClass;
	}
	public List<ProductClass> getProductClasses() {
		return productClasses;
	}
	public void setProductClasses(List<ProductClass> productClasses) {
		this.productClasses = productClasses;
	}
	public void setProductDesignService(ProductDesignService productDesignService) {
		this.productDesignService = productDesignService;
	}
	public List<Specification> getSpecs() {
		return specs;
	}
	public void setSpecs(List<Specification> productClassSpecs) {
		this.specs = productClassSpecs;
	}	
	public String getSpecParentId() {
		return specParentId;
	}
	public void setSpecParentId(String specParentId) {
		this.specParentId = specParentId;
	}
	public String list() throws Exception {
		if (log.isDebugEnabled()) log.debug("list() executing...");
		List<ProductClass> allPC = productDesignService.findAllProductClasses();
		setProductClasses(allPC);
		if (log.isDebugEnabled()) log.debug("list() found "+allPC.size()+" results");
		
		return SUCCESS;
	}
	
	public String save() throws Exception {
		if (log.isDebugEnabled()) log.debug("save() executing...");
		try {
			if (getProductClass() != null) {
				productDesignService.save(getProductClass());
			}
		} catch (DataAccessException dae) {
			log.error("Error saving product class", dae);
			return ERROR;
		}
		return SUCCESS;
	}
	
	public String edit() throws Exception {
		if (log.isDebugEnabled()) log.debug("edit() executing...");
    	ActionContext context = ActionContext.getContext();
		if (classId == null) {
			// if not already set, try to get it from the request parameters
			Map requestParams = context.getParameters();
			classId = (String)requestParams.get("classId");
		}
		if (classId == null) { // create a new product concept
			productClass = productDesignService.createProductClass();
		}
		else {
			// retrieve an existing product concept and update
			productClass = productDesignService.findProductClass(classId);
		}
		return SUCCESS;
	}
	
	public String view() throws Exception {
	   	ActionContext context = ActionContext.getContext();
		if (classId == null) {
			// if not already set, try to get it from the request parameters
			Map requestParams = context.getParameters();
			classId = (String)requestParams.get("classId");
		}
		productClass = productDesignService.findProductClass(classId);
		if (productClass == null) {
			// TODO error handling
			return ERROR;
		}
		return SUCCESS;
	}
	
	public String listSpecs() throws Exception {
		ActionContext context = ActionContext.getContext();
		if (classId == null) {
			
			log.debug("classId: "+classId);
			if (productClass == null)
				log.debug("product class is null in the action");
			Map requestParams = context.getParameters();
			classId = (String)requestParams.get("classId");
			productClass = productDesignService.findProductClass(classId);
			
		}
		this.specParentId = classId;
		if (productClass == null) {
			productClass = productDesignService.findProductClass(classId);
			log.debug("product class refreshed with id: "+productClass.getId());
		}
		this.specs = productDesignService.getSpecifications(productClass);
		log.debug("number of specs returned: "+specs.size());
		
		return SUCCESS;
	}
}
