/**
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 with a permitted attribution clause (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.rapidtransform.com/legal/license.txt
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is Convelo Open Source.
 * 
 * The Initial Developer of the Original Code is Rapid Transform, Inc.
 * Portions created by Rapid Transform are Copyright (C) 2005,2006 Rapid Transform, Inc. 
 * All Rights Reserved.
 */
package com.rapidtransform.spec.client;

import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.dao.DataAccessException;

import com.opensymphony.xwork.ActionContext;
import com.opensymphony.xwork.ActionSupport;
import com.rapidtransform.spec.model.SpecCategory;
import com.rapidtransform.spec.service.SpecService;

/**
 * @author S. Werner
 *
 */
public class SpecCategoryAction extends ActionSupport {
	private static Log log = LogFactory.getLog(SpecCategoryAction.class);
	
	public SpecService specService;
	
	public SpecCategory category;
	public String categoryId;
	public List<SpecCategory> topLevelCategories;
	
	public SpecCategory getCategory() {
		return category;
	}

	public void setCategory(SpecCategory category) {
		this.category = category;
	}

	public String getCategoryId() {
		return categoryId;
	}

	public void setCategoryId(String categoryId) {
		this.categoryId = categoryId;
	}

	public List<SpecCategory> getTopLevelCategories() {
		return topLevelCategories;
	}

	public void setTopLevelCategories(List<SpecCategory> topLevelCategories) {
		this.topLevelCategories = topLevelCategories;
	}

	public void setSpecService(SpecService service) {
		this.specService = service;
	}
	
	public String list() throws Exception {
		topLevelCategories = specService.findTopLevelCategories();
		return SUCCESS;
	}
	
	public String save() throws Exception {
		if (log.isDebugEnabled()) log.debug("save() executing...");
		try {
			if (category != null) {
				category = specService.save(category);
			}
		} catch (DataAccessException dae) {
			log.error("Error saving spec category", dae);
			return ERROR;
		}
		return SUCCESS;
	}
	
	public String edit() throws Exception {
		if (log.isDebugEnabled()) log.debug("edit() executing...");
    	ActionContext context = ActionContext.getContext();
    	Map requestParams = context.getParameters();
		if (categoryId == null) {
			// if not already set, try to get it from the request parameters
			categoryId = (String)requestParams.get("categoryId");
		}
		if (categoryId == null) { // create a new product concept
			category = new SpecCategory();
		}
		else {
			// retrieve an existing category and update
			category = specService.findSpecCategory(categoryId);
		}
		return SUCCESS;
	}
	
	public String view() throws Exception {
	   	ActionContext context = ActionContext.getContext();
		if (categoryId == null) {
			// if not already set, try to get it from the request parameters
			Map requestParams = context.getParameters();
			categoryId = (String)requestParams.get("categoryId");
		}
		category = specService.findSpecCategory(categoryId);
		if (category == null) {
			// TODO error handling
			return ERROR;
		}
		return SUCCESS;
	}	
	
}
